@@ -1,4 +1,4 @@
-/*global EzWebExt, StyledElements*/
+/*global StyledElements*/
 
 (function () {
 
@@ -13,7 +13,7 @@
             return true;
         }
 
-        options = EzWebExt.merge({
+        options = Wirecloud.Utils.merge({
             'position': ['right-bottom', 'left-bottom']
         }, options);
 
@@ -67,6 +67,18 @@
         }
     };
 
+    SubMenuItem.prototype.enable = function enable() {
+        this.menuItem.enable();
+    };
+
+    SubMenuItem.prototype.disable = function disable() {
+        this.menuItem.disable();
+    };
+
+    SubMenuItem.prototype.setDisabled = function setDisabled(disabled) {
+        this.menuItem.setDisabled(disabled);
+    };
+
     SubMenuItem.prototype.destroy = function destroy() {
         if (this.menuItem) {
             this.menuItem.destroy();
