@@ -1,4 +1,25 @@
-/*global EzWebExt, StyledElements*/
+/*
+ *     Copyright (c) 2008-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+ *
+ *     This file is part of Wirecloud Platform.
+ *
+ *     Wirecloud Platform is free software: you can redistribute it and/or
+ *     modify it under the terms of the GNU Affero General Public License as
+ *     published by the Free Software Foundation, either version 3 of the
+ *     License, or (at your option) any later version.
+ *
+ *     Wirecloud is distributed in the hope that it will be useful, but WITHOUT
+ *     ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
+ *     License for more details.
+ *
+ *     You should have received a copy of the GNU Affero General Public License
+ *     along with Wirecloud Platform.  If not, see
+ *     <http://www.gnu.org/licenses/>.
+ *
+ */
+
+/*global StyledElements, Wirecloud*/
 
 (function () {
 
@@ -28,7 +49,7 @@
             'initialValue': '',
             'class': ''
         };
-        options = EzWebExt.merge(defaultOptions, options);
+        options = Wirecloud.Utils.merge(defaultOptions, options);
 
         StyledElements.StyledInputElement.call(this, options.initialValue, ['blur', 'change', 'focus']);
 
@@ -59,18 +80,22 @@
         this._onfocus = onfocus.bind(this);
         this._onblur = onblur.bind(this);
 
-        this.inputElement.addEventListener('mousedown', EzWebExt.stopPropagationListener, true);
-        this.inputElement.addEventListener('click', EzWebExt.stopPropagationListener, true);
+        this.inputElement.addEventListener('mousedown', Wirecloud.Utils.stopPropagationListener, true);
+        this.inputElement.addEventListener('click', Wirecloud.Utils.stopPropagationListener, true);
         this.inputElement.addEventListener('input', this._oninput, true);
         this.inputElement.addEventListener('focus', this._onfocus, true);
         this.inputElement.addEventListener('blur', this._onblur, true);
     };
     StyledTextArea.prototype = new StyledElements.StyledInputElement();
 
+    StyledTextArea.prototype.select = function select() {
+        this.inputElement.select();
+    };
+
     StyledTextArea.prototype.destroy = function destroy() {
 
-        this.inputElement.removeEventListener('mousedown', EzWebExt.stopPropagationListener, true);
-        this.inputElement.removeEventListener('click', EzWebExt.stopPropagationListener, true);
+        this.inputElement.removeEventListener('mousedown', Wirecloud.Utils.stopPropagationListener, true);
+        this.inputElement.removeEventListener('click', Wirecloud.Utils.stopPropagationListener, true);
         this.inputElement.removeEventListener('input', this._oninput, true);
         this.inputElement.removeEventListener('focus', this._onfocus, true);
         this.inputElement.removeEventListener('blur', this._onblur, true);
