@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2013 Universidad Politécnica de Madrid
+# Copyright (c) 2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 from optparse import make_option, OptionParser
@@ -117,7 +117,7 @@ class BaseCommand(object):
             output = self.handle(*args, **options)
             if output:
                 self.stdout.write(output)
-        except CommandError, e:
+        except CommandError as e:
             if show_traceback:
                 traceback.print_exc()
             else:
