@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
-# This file is part of Wirecluod.
+# This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 import requests
 from requests.auth import HTTPBasicAuth
 from urllib2 import URLError, HTTPError
@@ -60,7 +59,7 @@ def parse_usdl_from_url(url):
         content_type = parse_mime_type(response.headers.get('content-type'))[0]
         parser = USDLParser(response.content, content_type)
         usdl_info = parser.parse()
-    except (requests.ConnectionError, URLError, USDLParseException), e:
+    except (requests.ConnectionError, URLError, USDLParseException) as e:
         cache.set(cache_key, e, 2 * 60 * 60)
         raise
 
@@ -95,6 +94,18 @@ class MarketAdaptor(object):
         self._user = user
         self._passwd = passwd
 
+    def _process_store_info(self, element):
+        result = {
+            'name': element.get('name'),
+            'url': element.xpath(URL_XPATH)[0].text,
+            'registrationDate': element.xpath(DATE_XPATH)[0].text
+        }
+
+        if result['name'] not in self._stores:
+            self._stores[result['name']] = StoreClient(result['url'])
+
+        return result
+
     def _parse_offering(self, name, url, parsed_usdl, store, options):
 
         offerings = []
@@ -171,7 +182,7 @@ class MarketAdaptor(object):
         url = urljoin(self._marketplace_uri, "registration/stores/")
         try:
             response = requests.get(url, auth=HTTPBasicAuth(self._user, self._passwd))
-        except HTTPError, e:
+        except HTTPError as e:
             if e.code == 404:
                 return []
 
@@ -183,14 +194,7 @@ class MarketAdaptor(object):
         result = []
 
         for res in parsed_body.xpath(RESOURCE_XPATH):
-            store = {}
-            store['name'] = res.get('name')
-            url = res.xpath(URL_XPATH)[0].text
-            store['url'] = url
-            result.append(store)
-
-            if store['name'] not in self._stores:
-                self._stores[store['name']] = StoreClient(store['url'])
+            result.append(self._process_store_info(res))
 
         return result
 
@@ -199,30 +203,21 @@ class MarketAdaptor(object):
         url = urljoin(self._marketplace_uri, "registration/store/" + urlquote(store))
         try:
             response = requests.get(url, auth=HTTPBasicAuth(self._user, self._passwd))
-        except HTTPError, e:
+        except HTTPError as e:
             raise HTTPError(e.url, e.code, e.msg, None, None)
 
         if response.status_code != 200:
             raise HTTPError(response.url, response.status_code, response.reason, None, None)
 
         parsed_body = etree.fromstring(response.content)
-
-        result = {}
-        result['name'] = store
-        result['url'] = parsed_body.xpath(URL_XPATH)[0].text
-        result['registrationDate'] = parsed_body.xpath(DATE_XPATH)[0].text
-
-        if result['name'] not in self._stores:
-            self._stores[result['name']] = StoreClient(result['url'])
-
-        return result
+        return self._process_store_info(parsed_body)
 
     def get_all_services_from_store(self, store, **options):
 
         url = urljoin(self._marketplace_uri, "offering/store/" + urlquote(store) + "/offerings")
         try:
             response = requests.get(url, auth=HTTPBasicAuth(self._user, self._passwd))
-        except HTTPError, e:
+        except HTTPError as e:
             raise HTTPError(e.url, e.code, e.msg, None, None)
 
         if response.status_code != 200:
@@ -265,7 +260,7 @@ class MarketAdaptor(object):
         url = urljoin(self._marketplace_uri, "search/offerings/fulltext/" + urlquote_plus(search_string))
         try:
             response = requests.get(url, auth=HTTPBasicAuth(self._user, self._passwd))
-        except HTTPError, e:
+        except HTTPError as e:
             raise HTTPError(e.url, e.code, e.msg, None, None)
 
         if response.status_code != 200:
