@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
-# This file is part of Wirecluod.
+# This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 import json
 
 from django.http import HttpResponse
@@ -64,7 +63,7 @@ def get_market_user_data(user, market_user, market_name):
             user_data[user_data_entry.name] = None
 
     try:
-        user_data['idm_token'] = user.social_auth.filter(provider='fiware').select_related('tokens').get().tokens['access_token']
+        user_data['idm_token'] = user.social_auth.filter(provider='fiware').get().tokens['access_token']
     except:
         pass
 
@@ -83,7 +82,7 @@ class ServiceCollection(Resource):
         except:
             return HttpResponse(status=502)
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
 
 
 class ServiceSearchCollection(Resource):
@@ -98,7 +97,7 @@ class ServiceSearchCollection(Resource):
         except:
             return HttpResponse(status=502)
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; chaset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; chaset=UTF-8')
 
 
 class AllStoresServiceCollection(Resource):
@@ -112,15 +111,12 @@ class AllStoresServiceCollection(Resource):
         try:
             stores = adaptor.get_all_stores()
             for store in stores:
-                #This if is necesary in order to avoid an Http error
-                #caused by and store without name that cant be deleted
-                if store['name'] != '':
-                    store_services = adaptor.get_all_services_from_store(store['name'], **user_data)
-                    result['resources'].extend(store_services['resources'])
+                store_services = adaptor.get_all_services_from_store(store['name'], **user_data)
+                result['resources'].extend(store_services['resources'])
         except:
             return HttpResponse(status=502)
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
 
 
 class StoreCollection(Resource):
@@ -134,7 +130,7 @@ class StoreCollection(Resource):
         except:
             return HttpResponse(status=502)
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; chaset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; chaset=UTF-8')
 
 
 def start_purchase(request, market_user, market_name, store):
@@ -142,7 +138,7 @@ def start_purchase(request, market_user, market_name, store):
     adaptor = get_market_adaptor(market_user, market_name)
     user_data = get_market_user_data(request.user, market_user, market_name)
 
-    data = json.loads(request.raw_post_data)
+    data = json.loads(request.body)
 
     redirect_uri = get_absolute_reverse_url('wirecloud.fiware.store_redirect_uri', request)
     try:
@@ -150,4 +146,4 @@ def start_purchase(request, market_user, market_name, store):
     except:
         return HttpResponse(status=502)
 
-    return HttpResponse(json.dumps(result), mimetype='application/json; chaset=UTF-8')
+    return HttpResponse(json.dumps(result), content_type='application/json; chaset=UTF-8')
