@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2012 Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -20,12 +20,12 @@
  */
 
 /*jslint white: true, onevar: true, undef: true, nomen: false, eqeqeq: true, plusplus: true, bitwise: true, regexp: true, newcap: true, immed: true, strict: true */
-/*global alert, Constants, document, gettext, interpolate, LayoutManagerFactory, Template */
+/*global alert, document, gettext, interpolate, LayoutManagerFactory */
 "use strict";
 
 var PartsPainter = function(part_structure_element, dom_element){
     this.part_template_element = part_structure_element;
-    this.part_template = new Template(this.part_template_element);
+    this.part_template = new Wirecloud.Utils.Template(this.part_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -43,7 +43,7 @@ var PartsPainter = function(part_structure_element, dom_element){
             };
             resource_element = document.createElement('div');
             resource_element.className="part_resource";
-            resource_element.update(this.part_template.evaluate(resource_html));
+            resource_element.innerHTML = this.part_template.evaluate(resource_html);
             this.dom_element.appendChild(resource_element)
         }
     };
@@ -51,7 +51,7 @@ var PartsPainter = function(part_structure_element, dom_element){
 
 var LegalPainter = function(legal_structure_element, dom_element){
     this.legal_template_element = legal_structure_element;
-    this.legal_template = new Template(this.legal_template_element);
+    this.legal_template = new Wirecloud.Utils.Template(this.legal_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -70,7 +70,7 @@ var LegalPainter = function(legal_structure_element, dom_element){
                 };
                 resource_element = document.createElement('div');
                 resource_element.className="legal_resource";
-                resource_element.update(this.legal_template.evaluate(resource_html));
+                resource_element.innerHTML = this.legal_template.evaluate(resource_html);
                 clause_painter = new ClausePainter(Wirecloud.currentTheme.templates['legal_clause_template'], resource_element.getElementsByClassName('clause_list')[0]);
                 clause_painter.paint(legal_element.clauses);
 
@@ -88,7 +88,7 @@ var LegalPainter = function(legal_structure_element, dom_element){
 
 var ClausePainter = function(clause_structure_element, dom_element){
     this.clause_template_element = clause_structure_element;
-    this.clause_template = new Template(this.clause_template_element);
+    this.clause_template = new Wirecloud.Utils.Template(this.clause_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -105,7 +105,7 @@ var ClausePainter = function(clause_structure_element, dom_element){
             }
             resource_element = document.createElement('div');
             resource_element.className="clause_resource";
-            resource_element.update(this.clause_template.evaluate(resource_html));
+            resource_element.innerHTML = this.clause_template.evaluate(resource_html);
 
             this.dom_element.appendChild(resource_element)
         }
@@ -114,7 +114,7 @@ var ClausePainter = function(clause_structure_element, dom_element){
 
 var SlaPainter = function(sla_structure_element, dom_element){
     this.sla_template_element = sla_structure_element;
-    this.sla_template = new Template(this.sla_template_element);
+    this.sla_template = new Wirecloud.Utils.Template(this.sla_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -135,7 +135,7 @@ var SlaPainter = function(sla_structure_element, dom_element){
                 };
                 resource_element = document.createElement('div');
                 resource_element.className="sla_resource";
-                resource_element.update(this.sla_template.evaluate(resource_html));
+                resource_element.innerHTML = this.sla_template.evaluate(resource_html);
                 expresion_painter = new ExpresionPainter(Wirecloud.currentTheme.templates['sla_expresion_template'], resource_element.getElementsByClassName('expresions_list')[0]);
                 expresion_painter.paint(sla_element.slaExpresions);
 
@@ -153,7 +153,7 @@ var SlaPainter = function(sla_structure_element, dom_element){
 
 var ExpresionPainter = function(expresion_structure_element, dom_element){
     this.expresion_template_element = expresion_structure_element;
-    this.expresion_template = new Template(this.expresion_template_element);
+    this.expresion_template = new Wirecloud.Utils.Template(this.expresion_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -171,7 +171,7 @@ var ExpresionPainter = function(expresion_structure_element, dom_element){
             };
             resource_element = document.createElement('div');
             resource_element.className="slaExpresion_resource";
-            resource_element.update(this.expresion_template.evaluate(resource_html));
+            resource_element.innerHTML = this.expresion_template.evaluate(resource_html);
             variable_painter = new VariablePainter(Wirecloud.currentTheme.templates['sla_variable_template'], resource_element.getElementsByClassName('variable_list')[0]);
 
             if ('location' in slaExpresion_element) {
@@ -193,7 +193,7 @@ var ExpresionPainter = function(expresion_structure_element, dom_element){
 
 var VariablePainter = function(variable_structure_element, dom_element){
     this.variable_template_element = variable_structure_element;
-    this.variable_template = new Template(this.variable_template_element);
+    this.variable_template = new Wirecloud.Utils.Template(this.variable_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -212,7 +212,7 @@ var VariablePainter = function(variable_structure_element, dom_element){
             }
             resource_element = document.createElement('div');
             resource_element.className="slaVariable_resource";
-            resource_element.update(this.variable_template.evaluate(resource_html));
+            resource_element.innerHTML = this.variable_template.evaluate(resource_html);
 
             this.dom_element.appendChild(resource_element)
         }
@@ -221,7 +221,7 @@ var VariablePainter = function(variable_structure_element, dom_element){
 
 var PricingPainter = function(pricing_structure_element, dom_element){
     this.pricing_template_element = pricing_structure_element;
-    this.pricing_template = new Template(this.pricing_template_element);
+    this.pricing_template = new Wirecloud.Utils.Template(this.pricing_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -241,7 +241,7 @@ var PricingPainter = function(pricing_structure_element, dom_element){
 	    }
             resource_element = document.createElement('div');
             resource_element.className="pricing_resource";
-            resource_element.update(this.pricing_template.evaluate(resource_html));
+            resource_element.innerHTML = this.pricing_template.evaluate(resource_html);
 
             if ('priceComponents' in pricing_element && pricing_element.priceComponents.length > 0 && pricing_element.priceComponents[0].title !== '') {
                 pricing_component_painter = new PriceElementPainter(Wirecloud.currentTheme.templates['price_component_template'], resource_element.getElementsByClassName('price_components_list')[0]);
@@ -266,7 +266,7 @@ var PricingPainter = function(pricing_structure_element, dom_element){
 
 var PriceElementPainter = function(price_structure_element, dom_element){
     this.price_template_element = price_structure_element;
-    this.price_template = new Template(this.price_template_element);
+    this.price_template = new Wirecloud.Utils.Template(this.price_template_element);
     this.dom_element = dom_element;
 
     this.paint = function(resource){
@@ -286,7 +286,7 @@ var PriceElementPainter = function(price_structure_element, dom_element){
             }
             resource_element = document.createElement('div');
             resource_element.className="price_element_resource";
-            resource_element.update(this.price_template.evaluate(resource_html));
+            resource_element.innerHTML = this.price_template.evaluate(resource_html);
 
             this.dom_element.appendChild(resource_element)
         }
