@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global document, EzWebExt, LayoutManagerFactory, gettext, interpolate, StyledElements, Wirecloud */
+/*global LayoutManagerFactory, gettext, StyledElements, Wirecloud */
 
 (function () {
 
@@ -27,35 +27,46 @@
 
     var MAC_MIMETYPES = ['application/x-widget+mashable-application-component', 'application/x-operator+mashable-application-component', 'application/x-mashup+mashable-application-component'];
 
+    var CURRENCY_SYMBOL = {
+        'EUR': '€',
+        'GBP': '£',
+        'USD': '$'
+    };
+
     var is_mac_mimetype = function is_mac_mimetype(mimetype) {
         return MAC_MIMETYPES.indexOf(mimetype) !== -1;
     };
 
-    var install = function install(url, catalogue_view, store) {
-        var layoutManager, local_catalogue_view;
+    var install = function install(url, catalogue_view, store, monitor) {
+        var layoutManager, local_catalogue_view, market_id;
 
         local_catalogue_view = LayoutManagerFactory.getInstance().viewsByName.marketplace.viewsByName.local;
         layoutManager = LayoutManagerFactory.getInstance();
-        layoutManager._startComplexTask(gettext("Importing resource into local repository"), 3);
         layoutManager.logSubTask(gettext('Uploading resource'));
 
+        if (catalogue_view.catalogue.market_user !== 'public') {
+            market_id = catalogue_view.catalogue.market_user + '/' + catalogue_view.catalogue.market_name;
+        } else {
+            market_id = catalogue_view.catalogue.market_name;
+        }
+
         local_catalogue_view.catalogue.addResourceFromURL(url, {
             packaged: true,
             forceCreate: true,
             market_info: {
-                name: catalogue_view.catalogue.market_name,
+                name: market_id,
                 store: store
             },
             onSuccess: function () {
                 LayoutManagerFactory.getInstance().logSubTask(gettext('Resource installed successfully'));
                 LayoutManagerFactory.getInstance().logStep('');
 
-                local_catalogue_view.refresh_search_results();
+                local_catalogue_view.viewsByName.search.mark_outdated();
                 catalogue_view.refresh_search_results();
             },
             onFailure: function (msg) {
-                LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.ERROR_MSG);
-                LogManagerFactory.getInstance().log(msg);
+                Wirecloud.GlobalLogManager.log(msg);
+                (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
             },
             onComplete: function () {
                 LayoutManagerFactory.getInstance()._notifyPlatformReady();
@@ -63,8 +74,50 @@
         });
     };
 
-    var onClick = function onClick(url, catalogue_view, store) {
-        install(url, catalogue_view, store);
+    var onInstallClick = function onInstallClick(offering, catalogue_view) {
+        var layoutManager, monitor, i;
+
+        layoutManager = LayoutManagerFactory.getInstance();
+        monitor = layoutManager._startComplexTask(gettext("Importing offering resources into local repository"), 3);
+
+        for (i = 0; i < offering.resources.length; i++) {
+            if ('type' in offering.resources[i]) {
+                install(offering.resources[i].url, catalogue_view, offering.store);
+            }
+        }
+    };
+
+    var onUninstallClick = function onUninstallClick(offering, catalogue_view) {
+        var layoutManager, local_catalogue_view, monitor, i, count;
+
+        layoutManager = LayoutManagerFactory.getInstance();
+        local_catalogue_view = LayoutManagerFactory.getInstance().viewsByName.marketplace.viewsByName.local;
+        monitor = layoutManager._startComplexTask(gettext("Uninstalling offering resources"), 1);
+
+        count = offering.resources.length;
+        for (i = 0; i < offering.resources.length; i++) {
+            if ('type' in offering.resources[i]) {
+                local_catalogue_view.catalogue.uninstallResource(offering.resources[i], {
+                    onSuccess: function () {
+                        local_catalogue_view.viewsByName.search.mark_outdated();
+                        catalogue_view.viewsByName.search.mark_outdated();
+                    },
+                    onComplete: function () {
+                        if (--count === 0) {
+                            LayoutManagerFactory.getInstance()._notifyPlatformReady();
+                            catalogue_view.refresh_if_needed();
+                        }
+                    }
+                });
+            } else {
+                count -= 1;
+            }
+        }
+    };
+
+    var is_single_payment = function is_single_payment(offering) {
+        var pricing = offering.pricing[0];
+        return pricing.priceComponents.length === 1 && pricing.priceComponents[0].unit.toLowerCase() === 'single payment';
     };
 
     var OfferingPainter = function OfferingPainter(catalogue_view, offering_template, container, extra_context) {
@@ -77,7 +130,8 @@
         this.structure_template = offering_template;
         this.error_template = '<s:styledgui xmlns:s="http://wirecloud.conwet.fi.upm.es/StyledElements" xmlns:t="http://wirecloud.conwet.fi.upm.es/Template" xmlns="http://www.w3.org/1999/xhtml"><div class="alert alert-block alert-error"><t:message/></div></s:styledgui>';
         this.container = container;
-        if (typeof extra_context === 'object' || typeof extra_context === 'function') {
+        this.is_details_view = extra_context != null; // TODO
+        if (extra_context != null && (typeof extra_context === 'object' || typeof extra_context === 'function')) {
             this.extra_context = extra_context;
         } else {
             this.extra_context = {};
@@ -100,15 +154,15 @@
         if (typeof this.extra_context === 'function') {
             extra_context = this.extra_context(offering);
         } else {
-            extra_context = EzWebExt.clone(this.extra_context);
+            extra_context = Wirecloud.Utils.clone(this.extra_context);
         }
 
-        context = EzWebExt.merge(extra_context, {
+        context = Wirecloud.Utils.merge(extra_context, {
             'displayname': offering.getDisplayName(),
             'name': offering.name,
             'owner': offering.owner,
             'store': offering.store,
-            'version': offering.version.text,
+            'version': offering.version,
             'abstract': offering['abstract'],
             'description': offering.description,
             'type': function () {
@@ -174,46 +228,64 @@
                 local_catalogue_view = LayoutManagerFactory.getInstance().viewsByName.marketplace.viewsByName.local;
 
                 if (!this.catalogue_view.catalogue.is_purchased(this.offering) && ['widget', 'operator', 'mashup', 'pack'].indexOf(this.offering.type) !== -1) {
-                    button = new StyledElements.StyledButton({
-                        'class': 'mainbutton btn-success',
-                        'text': gettext('Buy')
-                    });
+                    if (offering.pricing.length == 0 || !('priceComponents' in offering.pricing[0])) {
+                        button = new StyledElements.StyledButton({
+                            'class': 'mainbutton btn-success',
+                            'text': gettext('Free')
+                        });
+                    } else if (is_single_payment(offering)) {
+                        button = new StyledElements.StyledButton({
+                            'class': 'mainbutton btn-warning',
+                            'text': offering.pricing[0].priceComponents[0].value + ' ' + CURRENCY_SYMBOL[offering.pricing[0].priceComponents[0].currency]
+                        });
+                    } else {
+                        button = new StyledElements.StyledButton({
+                            'class': 'mainbutton btn-warning',
+                            'text': gettext('Purchase')
+                        });
+                    }
                     button.addEventListener('click', this.catalogue_view.createUserCommand('buy', this.offering));
                     return button;
                 }
 
-                if (['widget', 'operator', 'mashup'].indexOf(this.offering.type) !== -1) {
+                if (['widget', 'operator', 'mashup', 'pack'].indexOf(this.offering.type) !== -1) {
 
-                    if (Wirecloud.LocalCatalogue.resourceExistsId(this.offering.resources[0].id)) {
+                    for (i = 0; i < this.offering.resources.length; i++) {
+                        if (!Wirecloud.LocalCatalogue.resourceExistsId(this.offering.resources[i].id)) {
+                            button = new StyledElements.StyledButton({
+                                'text': gettext('Install')
+                            });
+
+                            button.addEventListener('click', onInstallClick.bind(null, this.offering, this.catalogue_view));
+                            break;
+                        }
+                    }
+
+                    if (!button) {
                         button = new StyledElements.StyledButton({
                             'class': 'btn-danger',
                             'text': gettext('Uninstall')
                         });
-                        button.addEventListener('click', local_catalogue_view.createUserCommand('uninstall', this.offering.resources[0], this.catalogue_view));
-                    } else {
-
-                        button = new StyledElements.StyledButton({
-                            'text': gettext('Install')
-                        });
-
-                        button.addEventListener('click', onClick.bind(null, this.offering.resources[0].url, this.catalogue_view, this.offering.store));
+                        button.addEventListener('click', onUninstallClick.bind(null, this.offering, this.catalogue_view));
                     }
-                } else {
+                } else if (!this.is_details_view) {
                     button = new StyledElements.StyledButton({
                         'text': gettext('Details')
                     });
 
                     button.addEventListener('click', this.catalogue_view.createUserCommand('showDetails', this.offering));
+                } else {
+                    return null;
                 }
                 button.addClassName('mainbutton btn-primary');
                 return button;
-            }.bind({catalogue_view: this.catalogue_view, offering: offering}),
+            }.bind({catalogue_view: this.catalogue_view, offering: offering, is_details_view: this.is_details_view}),
             'image': function () {
                 var image = document.createElement('img');
                 image.onerror = function (event) {
                     event.target.src = '/static/images/noimage.png';
                 };
-                image.src = offering.getUriImage();
+                image.src = offering.image;
                 return image;
             },
             'tags': function (options) {
@@ -225,17 +297,20 @@
 
         // TODO "Show details"
         for (i = 0; i < offering_element.elements.length; i += 1) {
-            if (!EzWebExt.XML.isElement(offering_element.elements[i])) {
+            if (!Wirecloud.Utils.XML.isElement(offering_element.elements[i])) {
                 continue;
             }
             this.create_simple_command(offering_element.elements[i], '.click_for_details', 'click', this.catalogue_view.createUserCommand('showDetails', offering));
+            if (offering_element.elements[i].classList.contains('click_for_details')) {
+                offering_element.elements[i].addEventListener('click', this.catalogue_view.createUserCommand('showDetails', offering));
+            }
         }
 
         return offering_element;
     };
 
     OfferingPainter.prototype.create_simple_command = function (element, selector, _event, handler, required) {
-        var i, elements = element.getElementsBySelector(selector);
+        var i, elements = element.querySelectorAll(selector);
 
         if (required && elements.length < 1) {
             throw new Error();
@@ -249,6 +324,10 @@
     OfferingPainter.prototype.get_popularity_html = function (popularity) {
         var on_stars, md_star, off_stars, stars, star, i;
 
+        if (popularity == null || popularity < 1) {
+            popularity = 0;
+        }
+
         on_stars = Math.floor(popularity);
         md_star = popularity - on_stars;
         off_stars = 5 - popularity;
@@ -256,6 +335,10 @@
         stars = document.createElement('div');
         stars.className = 'rating';
 
+        if (popularity === 0) {
+            stars.classList.add('disabled');
+        }
+
         // "On" stars
         for (i = 0; i < on_stars; i += 1) {
             star = document.createElement('span');
@@ -265,7 +348,7 @@
 
         if (md_star) {
             star = document.createElement('span');
-            star.className = 'md star';
+            star.className = 'middle star';
             stars.appendChild(star);
         }
 
