@@ -28,10 +28,11 @@ from django.utils.translation import ugettext as _
 from django.views.decorators.http import require_GET, require_POST
 
 from wirecloud.catalogue.models import CatalogueResource
-from wirecloud.commons.utils import downloader
+from wirecloud.commons.utils.downloader import download_http_content
 from wirecloud.commons.utils.http import build_error_response, get_content_type
 from wirecloud.commons.utils.template import TemplateParser, TemplateParseException
 from wirecloud.commons.utils.template.writers.rdf import write_rdf_description
+from wirecloud.commons.utils.transaction import commit_on_http_success
 from wirecloud.commons.utils.wgt import WgtFile
 from wirecloud.platform.localcatalogue.utils import install_resource_to_user
 from wirecloud.platform.workspace.mashupTemplateParser import buildWorkspaceFromTemplate
@@ -52,15 +53,23 @@ def parse_username(tenant_id):
 
 
 @require_POST
+@commit_on_http_success
 def add_tenant(request):
 
     try:
-        data = json.loads(request.raw_post_data)
-    except ValueError, e:
+        data = json.loads(request.body)
+    except ValueError as e:
         msg = _("malformed json data: %s") % unicode(e)
         return build_error_response(request, 400, msg)
 
     id_4CaaSt = data['4CaaStID']
+
+    if id_4CaaSt is None:
+        return build_error_response(request, 400, _('Missing 4CaaStID'))
+
+    if not isinstance(id_4CaaSt, basestring) or id_4CaaSt.strip() == '':
+        return build_error_response(request, 400, _('Invalid 4CaaStID'))
+
     username = parse_username(id_4CaaSt)
 
     status = 201
@@ -84,15 +93,23 @@ def add_tenant(request):
 
 
 @require_POST
+@commit_on_http_success
 def remove_tenant(request):
 
     try:
-        data = json.loads(request.raw_post_data)
-    except ValueError, e:
+        data = json.loads(request.body)
+    except ValueError as e:
         msg = _("malformed json data: %s") % unicode(e)
         return build_error_response(request, 400, msg)
 
-    id_4CaaSt = data['4CaaStID']
+    id_4CaaSt = data.get('4CaaStID')
+
+    if id_4CaaSt is None:
+        return build_error_response(request, 400, _('Missing 4CaaStID'))
+
+    if not isinstance(id_4CaaSt, basestring) or id_4CaaSt.strip() == '':
+        return build_error_response(request, 400, _('Invalid 4CaaStID'))
+
     username = parse_username(id_4CaaSt)
 
     user = get_object_or_404(User, username=username)
@@ -113,8 +130,8 @@ def _parse_ac_request(request):
     content_type = get_content_type(request)[0]
 
     try:
-        data = json.loads(request.raw_post_data)
-    except Exception, e:
+        data = json.loads(request.body)
+    except Exception as e:
         msg = _("malformed json data: %s") % unicode(e)
         return build_error_response(request, 400, msg)
 
@@ -124,10 +141,16 @@ def _parse_ac_request(request):
     fileURL = data.get('url')
     id_4CaaSt = data.get('4CaaStID')
 
+    if id_4CaaSt is None:
+        return build_error_response(request, 400, _('Missing 4CaaStID'))
+
+    if not isinstance(id_4CaaSt, basestring) or id_4CaaSt.strip() == '':
+        return build_error_response(request, 400, _('Invalid 4CaaStID'))
+
     try:
-        downloaded_file = downloader.download_http_content(fileURL)
+        downloaded_file = download_http_content(fileURL)
     except:
-        return build_error_response(request, 409, _('Widget content could not be downloaded'))
+        return build_error_response(request, 409, _('Mashable application component could not be downloaded'))
 
     downloaded_file = StringIO(downloaded_file)
     file_contents = WgtFile(downloaded_file)
@@ -161,6 +184,7 @@ def _parse_ac_request(request):
     return id_4CaaSt, file_contents, fileURL
 
 @require_POST
+@commit_on_http_success
 def deploy_tenant_ac(request):
 
     result = _parse_ac_request(request)
@@ -179,20 +203,25 @@ def deploy_tenant_ac(request):
 
         resource = install_resource_to_user(user, file_contents=wgt_file, templateURL=fileURL, packaged=True)
 
-    except TemplateParseException, e:
+    except TemplateParseException as e:
 
         return build_error_response(request, 400, unicode(e.msg))
 
     # Create a workspace if the resource is a mashup
     if resource.resource_type() == 'mashup' and not Workspace.objects.filter(creator=user, name=resource.display_name).exists():
-        buildWorkspaceFromTemplate(template, user, True)
+        buildWorkspaceFromTemplate(resource.get_template(), user, True)
 
     return HttpResponse(status=204)
 
 @require_POST
+@commit_on_http_success
 def undeploy_tenant_ac(request):
 
-    id_4CaaSt, wgt_file, fileURL = _parse_ac_request(request)
+    result = _parse_ac_request(request)
+    if isinstance(result, HttpResponse):
+        return result
+
+    id_4CaaSt, wgt_file, fileURL = result
 
     # Process 4CaaSt Id
     username = parse_username(id_4CaaSt)
@@ -207,7 +236,7 @@ def undeploy_tenant_ac(request):
     # If the resource is a mashup, remove the assigned workspace
     template = TemplateParser(wgt_file.get_template())
     if template.get_resource_type() == 'mashup':
-        Workspace.objects.filter(creator=user, name=template.get_resource_info()['display_name']).delete()
+        Workspace.objects.filter(creator=user, name=template.get_resource_info()['title']).delete()
 
     # Uninstall de resource
     template = TemplateParser(wgt_file.get_template())
@@ -218,6 +247,7 @@ def undeploy_tenant_ac(request):
 
 
 @require_GET
+@commit_on_http_success
 def add_saas_tenant(request, creator, workspace):
 
     # Sync workspace list before searching it
@@ -228,7 +258,14 @@ def add_saas_tenant(request, creator, workspace):
 
     status = 201
 
-    id_4CaaSt = request.GET['message']
+    id_4CaaSt = request.GET.get('message')
+
+    if id_4CaaSt is None:
+        return build_error_response(request, 400, _('Missing 4CaaStID'))
+
+    if not isinstance(id_4CaaSt, basestring) or id_4CaaSt.strip() == '':
+        return build_error_response(request, 400, _('Invalid 4CaaStID'))
+
     username = parse_username(id_4CaaSt)
     try:
         user = User.objects.create_user(username, 'test@example.com', username)
@@ -253,9 +290,17 @@ def add_saas_tenant(request, creator, workspace):
 
 
 @require_GET
+@commit_on_http_success
 def remove_saas_tenant(request, creator, workspace):
 
-    id_4CaaSt = request.GET['message']
+    id_4CaaSt = request.GET.get('message')
+
+    if id_4CaaSt is None:
+        return build_error_response(request, 400, _('Missing 4CaaStID'))
+
+    if not isinstance(id_4CaaSt, basestring) or id_4CaaSt.strip() == '':
+        return build_error_response(request, 400, _('Invalid 4CaaStID'))
+
     username = parse_username(id_4CaaSt)
 
     db_filter = {
