@@ -1,32 +1,46 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2013 Universidad Politécnica de Madrid
+# Copyright (c) 2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
+import json
 
 from django.contrib.auth.decorators import login_required
-from django.views.decorators.http import require_http_methods, require_POST
+from django.http import HttpResponse
+from django.views.decorators.http import require_GET, require_http_methods, require_POST
 from django.shortcuts import render
 
+from wirecloud.commons.utils.http import get_absolute_reverse_url
 from wirecloud.oauth2provider.provider import WirecloudAuthorizationProvider
 
 
 provider = WirecloudAuthorizationProvider()
 
+@require_GET
+def oauth_discovery(request):
+
+    endpoints = {
+        'auth_endpoint': get_absolute_reverse_url('oauth2provider.auth', request),
+        'token_endpoint': get_absolute_reverse_url('oauth2provider.token', request),
+        'default_redirect_uri': get_absolute_reverse_url('oauth.default_redirect_uri', request),
+        'version': '2.0',
+    }
+
+    return HttpResponse(json.dumps(endpoints), content_type='application/json; charset=UTF-8')
 
 @require_http_methods(["GET", "POST"])
 @login_required
