@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global $, gettext, LayoutManagerFactory, OpManagerFactory, StyledElements, Wirecloud*/
+/*global gettext, LayoutManagerFactory, OpManagerFactory, StyledElements, Wirecloud*/
 
 (function () {
 
@@ -32,8 +32,8 @@
     var WirecloudHeader = function WirecloudHeader() {
         var menu_wrapper;
 
-        this.wrapperElement = $('wirecloud_header');
-        this.breadcrum = $('wirecloud_breadcrum');
+        this.wrapperElement = document.getElementById('wirecloud_header');
+        this.breadcrum = document.getElementById('wirecloud_breadcrum');
         this.oil_header = this.wrapperElement.getElementsByTagName('header')[0];
 
         this.currentView = null;
@@ -78,10 +78,10 @@
     };
 
     WirecloudHeader.prototype._initUserMenu = function _initUserMenu() {
-        var user_menu, wrapper;
+        var user_menu, wrapper, login_button, item;
 
-        var username = OpManagerFactory.getInstance().contextManager.get('username');
-        var full_name = OpManagerFactory.getInstance().contextManager.get('fullname').trim();
+        var username = Wirecloud.contextManager.get('username');
+        var full_name = Wirecloud.contextManager.get('fullname').trim();
 
         wrapper = document.createElement('div');
         wrapper.className = 'nav pull-right';
@@ -90,7 +90,7 @@
         var li = document.createElement('li');
         wrapper.appendChild(li);
         var anchor = document.createElement('a');
-        anchor.setAttribute('href', 'https://account.lab.fi-ware.eu/users/' + username);
+        anchor.setAttribute('href', Wirecloud.constants.FIWARE_IDM_SERVER + '/users/' + username);
         anchor.setAttribute('target', '_blank');
         li.appendChild(anchor);
         var img = document.createElement('img');
@@ -112,39 +112,51 @@
         this.user_button.insertInto(wrapper);
 
         user_menu = this.user_button.getPopupMenu();
-        user_menu.append(new StyledElements.MenuItem(gettext('Settings'), OpManagerFactory.getInstance().showPlatformPreferences));
+        item = new StyledElements.MenuItem(gettext('Settings'), OpManagerFactory.getInstance().showPlatformPreferences);
+        user_menu.append(item);
+        item.setDisabled(username === 'anonymous');
 
-        if (OpManagerFactory.getInstance().contextManager.get('isstaff') === true && 'DJANGO_ADMIN' in Wirecloud.URLs) {
+        if (Wirecloud.contextManager.get('isstaff') === true && 'DJANGO_ADMIN' in Wirecloud.URLs) {
             user_menu.append(new StyledElements.MenuItem(gettext('DJango Admin panel'), function () {
                 window.open(Wirecloud.URLs.DJANGO_ADMIN, '_blank');
             }));
         }
-        user_menu.append(new Wirecloud.ui.TutorialSubMenu());
+        item = new Wirecloud.ui.TutorialSubMenu();
+        user_menu.append(item);
+        item.setDisabled(username === 'anonymous');
         user_menu.append(new StyledElements.Separator());
-        user_menu.append(new StyledElements.MenuItem(gettext('Sign out'), function () {
-            var portal_logout_urls = [
-                'http://cloud.lab.fi-ware.eu/logout',
-                'https://store.lab.fi-ware.eu/logout',
-                'https://mashup.lab.fi-ware.eu/logout',
-                'https://account.lab.fi-ware.eu/users/sign_out'
-            ];
-            var counter = portal_logout_urls.length;
-            for (var i = 0; i < portal_logout_urls.length; i += 1) {
-                Wirecloud.io.makeRequest(portal_logout_urls[i], {
-                    method: 'GET',
-                    supportsAccessControl: true,
-                    withCredentials: true,
-                    requestHeaders: {
-                        'X-Requested-With': null
-                    },
-                    onComplete: function () {
-                        if (--counter === 0) {
-                            window.location = 'http://lab.fi-ware.eu';
-                        }
+        if (username === 'anonymous') {
+            this.menu.innerHTML = '';
+
+            user_menu.append(new StyledElements.MenuItem(gettext('Sign in'), function () {
+                window.location = Wirecloud.URLs.LOGIN_VIEW + '?next=' + encodeURIComponent(window.location.pathname + window.location.search + window.location.hash);
+            }));
+        } else {
+            user_menu.append(new StyledElements.MenuItem(gettext('Sign out'), function () {
+                var portal_logout_urls, i, portal;
+
+                portal_logout_urls = [];
+                for (i = 0; i < Wirecloud.constants.FIWARE_PORTALS.length; i++) {
+                    portal = Wirecloud.constants.FIWARE_PORTALS[i];
+                    if ('logout_path' in portal) {
+                        portal_logout_urls.push(portal.url + portal.logout_path);
                     }
-                });
-            }
-        }));
+                };
+                for (i = 0; i < portal_logout_urls.length; i += 1) {
+                    Wirecloud.io.makeRequest(portal_logout_urls[i], {
+                        method: 'GET',
+                        supportsAccessControl: true,
+                        withCredentials: true,
+                        requestHeaders: {
+                            'X-Requested-With': null
+                        }
+                    });
+                }
+                setTimeout(function () {
+                    window.location = Wirecloud.constants.FIWARE_HOME;
+                }, 1000);
+            }));
+        }
     };
 
     WirecloudHeader.prototype._clearOldBreadcrum = function _clearOldBreadcrum() {
@@ -165,7 +177,7 @@
 
         this._clearOldBreadcrum();
 
-        if ('getBreadcrum' in newView) {
+        if (newView != null && 'getBreadcrum' in newView) {
             breadcrum = newView.getBreadcrum();
         } else {
             return;
@@ -179,7 +191,7 @@
         breadcrum_part.textContent = breadcrum_entry.label;
         breadcrum_part.className = breadcrum_levels[0];
         if ('class' in breadcrum_entry) {
-            breadcrum_part.addClassName(breadcrum_entry['class']);
+            breadcrum_part.classList.add(breadcrum_entry['class']);
         }
         this.breadcrum.appendChild(breadcrum_part);
 
@@ -193,10 +205,10 @@
             breadcrum_part.textContent = breadcrum_entry.label;
             breadcrum_part.className = breadcrum_levels[i];
             if ('class' in breadcrum_entry) {
-                breadcrum_part.addClassName(breadcrum_entry['class']);
+                breadcrum_part.classList.add(breadcrum_entry['class']);
             }
 
-            if ('menu' in breadcrum_entry) {
+            if (breadcrum_entry.menu != null) {
                 button = new StyledElements.PopupButton({
                     'plain': true,
                     'class': 'icon-menu',
@@ -213,12 +225,12 @@
         var menuitems, triangle, startx;
 
         if (this.currentMenu !== null) {
-            this.currentMenu.html_element.removeClassName('selected');
+            this.currentMenu.html_element.classList.remove('selected');
         }
 
         this.currentView = newView;
         this.currentMenu = this.menues[newView.view_name];
-        this.currentMenu.html_element.addClassName('selected');
+        this.currentMenu.html_element.classList.add('selected');
 
         this.refresh();
     };
@@ -226,7 +238,7 @@
     WirecloudHeader.prototype._notifyWorkspaceLoaded = function _notifyWorkspaceLoaded(workspace) {
         if (this.footer == null) {
             this.footer = document.createElement('footer');
-            this.footer.innerHTML = '<div>2013 © <a href="http://fi-ware.eu/">FI-WARE</a>. The use of FI-LAB services is subject to the acceptance of the <a href="http://wiki.fi-ware.eu/FI-LAB_Terms_and_Conditions">Terms and Conditions</a> and the <a href="http://forge.fi-ware.eu/plugins/mediawiki/wiki/fiware/index.php/FI-LAB_Personal_Data_Protection_Policy">Personal Data Protection Policy</a></div>';
+            this.footer.innerHTML = '<div>2014 © <a href="http://fi-ware.org/">FI-WARE</a>. The use of FI-LAB services is subject to the acceptance of the <a href="http://wiki.fi-ware.org/FI-LAB_Terms_and_Conditions">Terms and Conditions</a> and the <a href="http://forge.fi-ware.org/plugins/mediawiki/wiki/fiware/index.php/FI-LAB_Personal_Data_Protection_Policy">Personal Data Protection Policy</a></div>';
             LayoutManagerFactory.getInstance().mainLayout.getSouthContainer().appendChild(this.footer);
             LayoutManagerFactory.getInstance().mainLayout.repaint();
         }
