@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -71,15 +71,17 @@ class LocalCatalogueTestCase(WirecloudTestCase):
         self.assertEqual(data['name'], 'test')
         self.assertEqual(data['version'], '0.1')
         self.assertEqual(data['description'], 'Test Widget description')
-        self.assertEqual(data['image_uri'], 'http://example.com/path/images/catalogue.png')
-        self.assertEqual(data['iphone_image_uri'], 'http://example.com/path/images/catalogue_iphone.png')
-        self.assertEqual(data['doc_uri'], 'http://example.com/path/doc/index.html')
+        self.assertEqual(data['image'], 'http://example.com/path/images/catalogue.png')
+        self.assertEqual(data['smartphoneimage'], 'http://example.com/path/images/catalogue_iphone.png')
+        self.assertEqual(data['doc'], 'http://example.com/path/doc/index.html')
+        self.assertEqual(data['license'], 'Apache License 2.0')
+        self.assertEqual(data['licenseurl'], 'http://www.apache.org/licenses/LICENSE-2.0.html')
 
         self.assertEqual(len(data['properties']), 1)
-        self.assertEqual(data['properties'], [{u'default_value': u'', u'secure': False, u'name': u'prop', u'label': u'Property label', u'type': u'text', u'description': u''}])
+        self.assertEqual(data['properties'], [{u'default': u'', u'secure': False, u'name': u'prop', u'label': u'Property label', u'type': u'text', u'description': u''}])
 
         self.assertEqual(len(data['preferences']), 1)
-        self.assertEqual(data['preferences'], [{u'default_value': u'value', u'secure': False, u'name': u'pref', u'label': u'Preference label', u'type': u'list', u'options': [{u'value': u'1', u'label': u'Option name'}], u'readonly': False, u'description': u'Preference description', u'value': None}])
+        self.assertEqual(data['preferences'], [{u'default': u'value', u'secure': False, u'name': u'pref', u'label': u'Preference label', u'type': u'list', u'options': [{u'value': u'1', u'label': u'Option name'}], u'readonly': False, u'description': u'Preference description', u'value': None}])
 
         self.assertEqual(len(data['wiring']['inputs']), 1)
         self.assertEqual(data['wiring']['inputs'], [{u'name': u'slot', u'label': u'Slot label', u'type': u'text', u'description': u'',u'friendcode': u'test_friend_code', u'actionlabel': u''}])
@@ -87,6 +89,23 @@ class LocalCatalogueTestCase(WirecloudTestCase):
         self.assertEqual(len(data['wiring']['outputs']), 1)
         self.assertEqual(data['wiring']['outputs'], [{u'name': u'event', u'label': u'Event label', u'type': u'text', u'description': u'', u'friendcode': u'test_friend_code'}])
 
+    def test_widget_with_minimal_info(self):
+
+        template_uri = "http://example.com/path/widget.xml"
+        template = self.read_template('template9.xml')
+
+        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
+        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
+        resource = install_resource_to_user(self.user, file_contents=template, templateURL=template_uri)
+
+        self.assertEqual(resource.vendor, 'Wirecloud')
+        self.assertEqual(resource.short_name, 'test')
+        self.assertEqual(resource.version, '0.1')
+        self.assertEqual(resource.mail, 'test@example.com')
+        self.assertEqual(resource.public, False)
+        self.assertEqual(tuple(resource.users.values_list('username', flat=True)), (u'test',))
+        self.assertEqual(tuple(resource.groups.values_list('name', flat=True)), ())
+
     def test_basic_widget_creation(self):
         template_uri = "http://example.com/path/widget.xml"
         template = self.read_template('template1.xml')
@@ -104,16 +123,6 @@ class LocalCatalogueTestCase(WirecloudTestCase):
 
         self.check_basic_widget_info(resource)
 
-    def test_basic_ezweb_widget_creation(self):
-        template_uri = "http://example.com/path/widget.xml"
-        template = self.read_template('old-template.xml')
-
-        self.network._servers['http']['example.com'].add_response('GET', '/path/widget.xml', {'content': template})
-        self.network._servers['http']['example.com'].add_response('GET', '/path/test.html', {'content': BASIC_HTML_GADGET_CODE})
-        resource = install_resource(template, template_uri, self.user, False)
-
-        self.check_basic_widget_info(resource)
-
     def test_basic_widget_creation_from_rdf(self):
         template_uri = "http://example.com/path/widget.rdf"
         template = self.read_template('template1.rdf')
@@ -147,7 +156,7 @@ class LocalCatalogueTestCase(WirecloudTestCase):
         self.assertEqual(data['wiring']['outputs'][0]['friendcode'], 'test_friend_code')
         self.assertEqual(data['preferences'][0]['label'], 'Preference label')
         self.assertEqual(data['preferences'][0]['description'], 'Preference description')
-        self.assertEqual(data['preferences'][0]['default_value'], 'value')
+        self.assertEqual(data['preferences'][0]['default'], 'value')
         self.assertEqual(len(data['js_files']), 5)
 
         self.assertEqual(data['js_files'][0], '/examplecode1.js')
@@ -159,7 +168,7 @@ class LocalCatalogueTestCase(WirecloudTestCase):
     def test_widget_deletion(self):
         resource = CatalogueResource.objects.get(vendor='Test', short_name='Test Widget', version='1.0.0')
         resource_pk = resource.pk
-        xhtml_pk = resource.widget.pk
+        xhtml_pk = resource.widget.xhtml.pk
 
         resource.delete()
         self.assertRaises(XHTML.DoesNotExist, XHTML.objects.get, pk=xhtml_pk)
@@ -236,17 +245,17 @@ class LocalCatalogueTestCase(WirecloudTestCase):
         self.assertEqual(data['vendor'], 'Wirecloud')
         self.assertEqual(data['name'], 'test')
         self.assertEqual(data['version'], '0.1')
-        self.assertEqual(data['display_name'], 'Widget de prueba')
+        self.assertEqual(data['title'], 'Widget de prueba')
         self.assertEqual(data['description'], u'Descripción del Widget de pruebas')
-        self.assertEqual(data['image_uri'], 'http://example.com/path/images/catalogue.png')
-        self.assertEqual(data['iphone_image_uri'], 'http://example.com/path/images/catalogue_iphone.png')
-        self.assertEqual(data['doc_uri'], 'http://example.com/path/doc/index.html')
+        self.assertEqual(data['image'], 'http://example.com/path/images/catalogue.png')
+        self.assertEqual(data['smartphoneimage'], 'http://example.com/path/images/catalogue_iphone.png')
+        self.assertEqual(data['doc'], 'http://example.com/path/doc/index.html')
 
         self.assertEqual(len(data['properties']), 1)
-        self.assertEqual(data['properties'], [{u'default_value': u'', u'secure': False, u'name': u'prop', u'label': u'Etiqueta de la propiedad', u'type': u'text', u'description': u''}])
+        self.assertEqual(data['properties'], [{u'default': u'', u'secure': False, u'name': u'prop', u'label': u'Etiqueta de la propiedad', u'type': u'text', u'description': u''}])
 
         self.assertEqual(len(data['preferences']), 1)
-        self.assertEqual(data['preferences'], [{u'default_value': u'value', u'secure': False, u'name': u'pref', u'label': u'Etiqueta de la preferencia', u'type': u'list', u'options': [{u'value': u'1', u'label': u'Nombre de la opción'}], u'readonly': False, u'description': u'Descripción de la preferencia', u'value': None}])
+        self.assertEqual(data['preferences'], [{u'default': u'value', u'secure': False, u'name': u'pref', u'label': u'Etiqueta de la preferencia', u'type': u'list', u'options': [{u'value': u'1', u'label': u'Nombre de la opción'}], u'readonly': False, u'description': u'Descripción de la preferencia', u'value': None}])
 
         self.assertEqual(len(data['wiring']['inputs']), 1)
         self.assertEqual(data['wiring']['inputs'], [{u'name': u'slot', u'label': u'Etiqueta del endpoint de entrada', u'type': u'text', u'description': u'',u'friendcode': u'test_friend_code', u'actionlabel': u''}])
@@ -263,14 +272,14 @@ class LocalCatalogueTestCase(WirecloudTestCase):
         resource = install_resource(template, template_uri, self.user, False)
 
         data = resource.get_processed_info()
-        self.assertEqual(data['display_name'], 'Test Widget')
+        self.assertEqual(data['title'], 'Test Widget')
         self.assertEqual(data['version'], '0.2')
 
         self.assertEqual(len(data['properties']), 1)
-        self.assertEqual(data['properties'], [{u'default_value': u'', u'secure': False, u'name': u'prop', u'label': u'Label', u'type': u'text', u'description': u''}])
+        self.assertEqual(data['properties'], [{u'default': u'', u'secure': False, u'name': u'prop', u'label': u'Label', u'type': u'text', u'description': u''}])
 
         self.assertEqual(len(data['preferences']), 1)
-        self.assertEqual(data['preferences'], [{u'default_value': u'value', u'secure': False, u'name': u'pref', u'label': u'Label', u'readonly': False, u'type': u'text', u'description': u'Preference description', u'value': None}])
+        self.assertEqual(data['preferences'], [{u'default': u'value', u'secure': False, u'name': u'pref', u'label': u'Label', u'readonly': False, u'type': u'text', u'description': u'Preference description', u'value': None}])
 
         self.assertEqual(len(data['wiring']['inputs']), 1)
         self.assertEqual(data['wiring']['inputs'], [{u'name': u'slot', u'label': u'Label', u'type': u'text', u'description': u'',u'friendcode': u'test_friend_code', u'actionlabel': u''}])
@@ -516,6 +525,12 @@ class LocalCatalogueSeleniumTests(WirecloudSeleniumTestCase):
         widget = self.search_in_catalogue_results('Test')
         self.assertIsNone(widget)
 
+    def test_public_resources_are_uninstallable(self):
+
+        self.login(username='normuser')
+
+        self.uninstall_resource('Test', expect_error=True)
+
     def test_resource_uninstall(self):
 
         test_widget = CatalogueResource.objects.get(short_name='Test')
