@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Universidad Politécnica de Madrid
+# Copyright 2008-2014 Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -20,7 +20,7 @@
 import json
 
 from django.core.cache import cache
-from django.http import HttpResponse, HttpResponseForbidden
+from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
 from django.utils.translation import gettext_lazy as _
 
@@ -146,20 +146,22 @@ def update_workspace_preferences(workspace, preferences_json):
 
 class PlatformPreferencesCollection(Resource):
 
-    @authentication_required
     @no_cache
     def read(self, request):
-        result = parseValues(PlatformPreference.objects.filter(user=request.user))
+        if request.user.is_authenticated():
+            result = parseValues(PlatformPreference.objects.filter(user=request.user))
+        else:
+            result = {}
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
 
     @authentication_required
     @supported_request_mime_types(('application/json',))
     @commit_on_http_success
     def create(self, request):
         try:
-            preferences_json = json.loads(request.raw_post_data)
-        except ValueError, e:
+            preferences_json = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
@@ -180,11 +182,11 @@ class WorkspacePreferencesCollection(Resource):
         # Check Workspace existance and owned by this user
         workspace = get_object_or_404(Workspace, pk=workspace_id)
         if not (request.user.is_superuser or workspace.users.filter(pk=request.user.pk).exists()):
-            return HttpResponseForbidden()
+            return build_error_response(request, 403, _('You are not allowed to read this workspace'))
 
         result = get_workspace_preference_values(workspace.id)
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
 
     @authentication_required
     @supported_request_mime_types(('application/json',))
@@ -194,15 +196,21 @@ class WorkspacePreferencesCollection(Resource):
         # Check Workspace existance and owned by this user
         workspace = get_object_or_404(Workspace, pk=workspace_id)
         if not (request.user.is_superuser or workspace.users.filter(pk=request.user.pk).exists()):
-            return HttpResponseForbidden()
+            return build_error_response(request, 403, _('You are not allowed to update this workspace'))
 
         try:
-            preferences_json = json.loads(request.raw_post_data)
-        except ValueError, e:
+            preferences_json = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
+        if 'public' in preferences_json:
+            workspace.public = preferences_json['public']['value']
+            workspace.save()
+            del preferences_json['public']
+
         update_workspace_preferences(workspace, preferences_json)
+
         return HttpResponse(status=204)
 
 
@@ -215,11 +223,11 @@ class TabPreferencesCollection(Resource):
         # Check Tab existance and owned by this user
         tab = get_object_or_404(Tab.objects.select_related('workspace'), workspace__pk=workspace_id, pk=tab_id)
         if not (request.user.is_superuser or tab.workspace.users.filter(pk=request.user.pk).exists()):
-            return HttpResponseForbidden()
+            return build_error_response(request, 403, _('You are not allowed to read this workspace'))
 
         result = get_tab_preference_values(tab)
 
-        return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
 
     @authentication_required
     @supported_request_mime_types(('application/json',))
@@ -229,11 +237,11 @@ class TabPreferencesCollection(Resource):
         # Check Tab existance and owned by this user
         tab = get_object_or_404(Tab.objects.select_related('workspace'), workspace__pk=workspace_id, pk=tab_id)
         if not (request.user.is_superuser or tab.workspace.users.filter(pk=request.user.pk).exists()):
-            return HttpResponseForbidden()
+            return build_error_response(request, 403, _('You are not allowed to update this workspace'))
 
         try:
-            preferences_json = json.loads(request.raw_post_data)
-        except ValueError, e:
+            preferences_json = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
