@@ -1,5 +1,5 @@
 /*jslint white: true, onevar: true, undef: true, nomen: true, eqeqeq: true, plusplus: true, bitwise: true, regexp: true, newcap: true, immed: true, strict: true */
-/*global $, Event, OpManagerFactory, MYMW, window, interpolate, gettext, LayoutManagerFactory, Wirecloud */
+/*global OpManagerFactory, MYMW, window, interpolate, gettext, LayoutManagerFactory, Wirecloud */
 "use strict";
 
 /* 
@@ -31,7 +31,7 @@
 * This class represents a instance of a Widget.
 * @author aarranz
 */
-function IWidget(widget, iWidgetId, iWidgetCode, iWidgetName, dragboard, alternative) {
+function IWidget(widget, iWidgetId, iWidgetCode, iWidgetName, dragboard, alternative, variables) {
     this.code = iWidgetCode;
 
     this.dragboard = dragboard;
@@ -44,7 +44,8 @@ function IWidget(widget, iWidgetId, iWidgetCode, iWidgetName, dragboard, alterna
         {
             id: iWidgetId,
             name: iWidgetName,
-            readOnly: true // TODO
+            readOnly: true, // TODO
+            variables: variables
         }
     );
     Object.defineProperties(this, {
@@ -103,7 +104,7 @@ IWidget.prototype.notifyEvent = function () {
  */
 IWidget.prototype.destroy = function () {
     if (this.element) {
-        this.element.remove();
+        Wirecloud.Utils.removeFromParent(this.element);
         this.element = null;
         this.content = null;
     }
