@@ -20,7 +20,7 @@
  */
 
 /*jslint white: true, onevar: false, undef: true, nomen: false, eqeqeq: true, plusplus: false, bitwise: true, regexp: true, newcap: true, immed: true, strict: false, forin: true, sub: true*/
-/*global gettext, Constants, DragboardLayout, DragboardPosition, IWidget, LayoutManagerFactory, MultiValuedSize*/
+/*global gettext, IWidget, LayoutManagerFactory*/
 
 /////////////////////////////////////
 // FreeLayout
@@ -31,7 +31,7 @@
  *
  * This dragobard uses percentages for horizontal units and px for vertical units.
  *
- * @extends DragboardLayout
+ * @extends Wirecloud.ui.DragboardLayout
  */
 function FreeLayout(dragboard, scrollbarSpace) {
     if (arguments.length === 0) {
@@ -40,9 +40,9 @@ function FreeLayout(dragboard, scrollbarSpace) {
 
     this.initialized = false;
     this.iwidgetToMove = null;
-    DragboardLayout.call(this, dragboard, scrollbarSpace);
+    Wirecloud.ui.DragboardLayout.call(this, dragboard, scrollbarSpace);
 }
-FreeLayout.prototype = new DragboardLayout();
+FreeLayout.prototype = new Wirecloud.ui.DragboardLayout();
 
 FreeLayout.prototype.MAX_HLU = 1000000;
 
@@ -84,25 +84,25 @@ FreeLayout.prototype.getRowOffset = function (row) {
 
 FreeLayout.prototype.adaptColumnOffset = function (pixels) {
     var offsetInLU = Math.ceil(this.fromPixelsToHCells(pixels));
-    return new MultiValuedSize(this.fromHCellsToPixels(offsetInLU), offsetInLU);
+    return new Wirecloud.ui.MultiValuedSize(this.fromHCellsToPixels(offsetInLU), offsetInLU);
 };
 
 FreeLayout.prototype.adaptRowOffset = function (pixels) {
-    return new MultiValuedSize(pixels, pixels);
+    return new Wirecloud.ui.MultiValuedSize(pixels, pixels);
 };
 
 FreeLayout.prototype.adaptHeight = function (contentHeight, fullSize, oldLayout) {
-    return new MultiValuedSize(contentHeight, fullSize);
+    return new Wirecloud.ui.MultiValuedSize(contentHeight, fullSize);
 };
 
 FreeLayout.prototype.adaptWidth = function (contentWidth, fullSize) {
     var widthInLU = Math.floor(this.fromPixelsToHCells(fullSize));
-    return new MultiValuedSize(this.fromHCellsToPixels(widthInLU), widthInLU);
+    return new Wirecloud.ui.MultiValuedSize(this.fromHCellsToPixels(widthInLU), widthInLU);
 };
 
 FreeLayout.prototype._notifyWindowResizeEvent = function (widthChanged, heightChanged) {
     if (widthChanged) {
-        DragboardLayout.prototype._notifyWindowResizeEvent.call(this, widthChanged, heightChanged);
+        Wirecloud.ui.DragboardLayout.prototype._notifyWindowResizeEvent.call(this, widthChanged, heightChanged);
     }
 };
 
@@ -142,19 +142,19 @@ FreeLayout.prototype.initialize = function () {
  * Calculate what cell is at a given position in pixels
  */
 FreeLayout.prototype.getCellAt = function (x, y) {
-    return new DragboardPosition((x * this.MAX_HLU) / this.getWidth(), y);
+    return new Wirecloud.DragboardPosition((x * this.MAX_HLU) / this.getWidth(), y);
 };
 
 FreeLayout.prototype.addIWidget = function (iWidget, affectsDragboard) {
-    DragboardLayout.prototype.addIWidget.call(this, iWidget, affectsDragboard);
+    Wirecloud.ui.DragboardLayout.prototype.addIWidget.call(this, iWidget, affectsDragboard);
 
     if (!this.initialized) {
         return;
     }
 
     var position = iWidget.getPosition();
-    if (!(position instanceof DragboardPosition)) {
-        position = new DragboardPosition(0, 0);
+    if (!(position instanceof Wirecloud.DragboardPosition)) {
+        position = new Wirecloud.DragboardPosition(0, 0);
     }
 
     iWidget.setPosition(position);
@@ -170,7 +170,7 @@ FreeLayout.prototype.initializeMove = function (iwidget, draggable) {
     // Check for pendings moves
     if (this.iwidgetToMove !== null) {
         msg = gettext("There was a pending move that was cancelled because initializedMove function was called before it was finished.");
-        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Wirecloud.constants.LOGGING.WARN_MSG);
         this.cancelMove();
     }
 
@@ -186,7 +186,7 @@ FreeLayout.prototype.initializeMove = function (iwidget, draggable) {
 FreeLayout.prototype.moveTemporally = function (x, y) {
     if (!(this.iwidgetToMove instanceof IWidget)) {
         var msg = gettext("Dragboard: You must call initializeMove function before calling to this function (moveTemporally).");
-        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Wirecloud.constants.LOGGING.WARN_MSG);
         return;
     }
 
@@ -197,7 +197,7 @@ FreeLayout.prototype.moveTemporally = function (x, y) {
 FreeLayout.prototype.acceptMove = function () {
     if (!(this.iwidgetToMove instanceof IWidget)) {
         var msg = gettext("Function acceptMove called when there is not an started iwidget move.");
-        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Wirecloud.constants.LOGGING.WARN_MSG);
         return;
     }
 
@@ -224,7 +224,7 @@ FreeLayout.prototype.cancelMove = function () {
 
     if (!(this.iwidgetToMove instanceof IWidget)) {
         msg = gettext("Trying to cancel an inexistant temporal move.");
-        Wirecloud.GlobalLogManager.log(msg, Constants.WARN_MSG);
+        Wirecloud.GlobalLogManager.log(msg, Wirecloud.constants.LOGGING.WARN_MSG);
         return;
     }
 
