@@ -20,10 +20,9 @@
  */
 
 /*jslint white: true, onevar: false, undef: true, nomen: false, eqeqeq: true, plusplus: false, bitwise: true, regexp: true, newcap: true, immed: true, strict: false, forin: true, sub: true*/
-/*global $, CSSPrimitiveValue, Event, Insertion, document, gettext, ngettext, interpolate, window */
-/*global Constants, DropDownMenu, LayoutManagerFactory, OpManagerFactory, Wirecloud*/
-/*global isElement, DragboardPosition*/
-/*global IWidgetDraggable, IWidgetIconDraggable, FreeLayout, FullDragboardLayout*/
+/*global CSSPrimitiveValue, Insertion, document, gettext, ngettext, interpolate, window */
+/*global DropDownMenu, LayoutManagerFactory, OpManagerFactory, Wirecloud*/
+/*global IWidgetIconDraggable, FreeLayout, FullDragboardLayout*/
 /*global ColorDropDownMenu*/
 
 /**
@@ -39,7 +38,7 @@
  *                                          iWidgets (not coming from
  *                                          persistence)
  * @param {String}            iWidgetName   current widget
- * @param {DragboardLayout}   layout        associated layout
+ * @param {Wirecloud.ui.DragboardLayout}   layout        associated layout
  * @param {DragboardPosition} position      initial position. This parameter can
  *                                          be null for new iWidgets (not coming
  *                                          from persistence)
@@ -54,7 +53,7 @@
  * @param {String}            menu_color    background color for the menu.
  *                                          (6 chars with a hexadecimal color)
  */
-function IWidget(widget, iWidgetId, iWidgetName, layout, position, iconPosition, zPos, width, height, fulldragboard, minimized, refusedVersion, freeLayoutAfterLoading, readOnly) {
+function IWidget(widget, iWidgetId, iWidgetName, layout, position, iconPosition, zPos, width, height, fulldragboard, minimized, refusedVersion, readOnly, variables) {
 
     this.code = null;
     this.position = position;
@@ -90,11 +89,14 @@ function IWidget(widget, iWidgetId, iWidgetName, layout, position, iconPosition,
         {
             id: iWidgetId,
             name: iWidgetName,
-            readOnly: readOnly
+            readOnly: readOnly,
+            variables: variables
         }
     );
-    this._updateErrorInfo.bind(this);
-    this.internal_iwidget.logManager.addEventListener('newentry', this._updateErrorInfo.bind(this));
+    this._iwidget_removed = this._iwidget_removed.bind(this);
+    this.internal_iwidget.addEventListener('removed', this._iwidget_removed);
+    this._updateErrorInfo = this._updateErrorInfo.bind(this);
+    this.internal_iwidget.logManager.addEventListener('newentry', this._updateErrorInfo);
     Object.defineProperties(this, {
         'id': {get: function () {return this.internal_iwidget.id;}},
         'widget': {get: function () {return this.internal_iwidget.widget;}},
@@ -105,7 +107,6 @@ function IWidget(widget, iWidgetId, iWidgetName, layout, position, iconPosition,
     }
 
     this.refusedVersion = refusedVersion !== null ? new Wirecloud.Version(refusedVersion) : null;
-    this.freeLayoutAfterLoading = freeLayoutAfterLoading; //only used the first time the widget is used to change its layout after loading to FreeLayout
 
     // Elements
     this.element = null;
@@ -155,7 +156,7 @@ IWidget.prototype.invalidIconPosition = function () {
 IWidget.prototype.setPosition = function (position) {
     // Set a initial icon position (first time) or it still follows the widget (both positions are a reference to the same object)
     if (!this.iconPosition) {
-        this.setIconPosition(new DragboardPosition(-1, -1));
+        this.setIconPosition(new Wirecloud.DragboardPosition(-1, -1));
     }
     if (this.onFreeLayout() && this.invalidIconPosition()) {
         this.setIconPosition(position);
@@ -261,7 +262,7 @@ IWidget.prototype.getContentHeight = function () {
  *
  * @returns {Number} the current width of the widget in LU
  *
- * @see DragboardLayout
+ * @see Wirecloud.ui.DragboardLayout
  */
 IWidget.prototype.getWidth = function () {
     // For now, the iwidget width is always the width of the iwidget content
@@ -275,7 +276,7 @@ IWidget.prototype.getWidth = function () {
  *
  * @returns {Number} the current height of the widget in LU
  *
- * @see DragboardLayout
+ * @see Wirecloud.ui.DragboardLayout
  */
 IWidget.prototype.getHeight = function () {
     return this.height;
@@ -325,10 +326,10 @@ IWidget.prototype.build = function () {
 
     // Icon Element
     this.iconElement = document.createElement("div");
-    this.iconElement.addClassName("floating_widget_icon");
+    this.iconElement.classList.add("floating_widget_icon");
 
     this.iconImg = document.createElement("img");
-    this.iconImg.addClassName("floating_widget_img");
+    this.iconImg.classList.add("floating_widget_img");
     this.iconImg.setAttribute("src", this.internal_iwidget.widget.getIcon());
     this.iconElement.appendChild(this.iconImg);
 
@@ -338,11 +339,11 @@ IWidget.prototype.build = function () {
     };
 
     this.iwidgetIconNameHTMLElement = document.createElement("a");
-    this.iwidgetIconNameHTMLElement.update(this.name);
-    this.iwidgetIconNameHTMLElement.addClassName("floating_widget_title");
+    this.iwidgetIconNameHTMLElement.textContent = this.name;
+    this.iwidgetIconNameHTMLElement.classList.add("floating_widget_title");
     this.iconElement.appendChild(this.iwidgetIconNameHTMLElement);
 
-    this.iwidgetIconNameHTMLElement.observe("click",
+    this.iwidgetIconNameHTMLElement.addEventListener("click",
         function () {
             this.toggleMinimizeStatus(false);
             this.layout.dragboard.raiseToTop(this);
@@ -382,6 +383,9 @@ IWidget.prototype.paint = function (onInit) {
 
     // Insert it into the dragboard (initially hidden)
     this.element.style.visibility = "hidden";
+    if (onInit) {
+        this.element.classList.add('in');
+    }
     this.layout.dragboard.dragboardElement.appendChild(this.element);
 
     // Position
@@ -399,7 +403,7 @@ IWidget.prototype.paint = function (onInit) {
 
     //Initialize read-only status
     if (this.internal_iwidget.readOnly) {
-        this.element.addClassName("widget_window_readonly");
+        this.element.classList.add("widget_window_readonly");
     }
 
     // Time to show the iwidget (we need to take into account the widget can be iconified)
@@ -408,7 +412,7 @@ IWidget.prototype.paint = function (onInit) {
     }
 
     // Mark as draggable
-    this.draggable = new IWidgetDraggable(this);
+    this.draggable = new Wirecloud.ui.IWidgetDraggable(this);
 
     // Notify Context Manager about the new position and new sizes
     this.internal_iwidget.contextManager.modify({
@@ -426,7 +430,7 @@ IWidget.prototype.paint = function (onInit) {
     this.iconElement.style.left = this.layout.dragboard.freeLayout.getColumnOffset(this.iconPosition.x) + "px";
     this.iconElement.style.top = this.layout.dragboard.freeLayout.getRowOffset(this.iconPosition.y) + "px";
 
-    Event.observe(this.iconImg,
+    this.iconImg.addEventListener(
         "click",
         function () {
             this.setMinimizeStatus(false);
@@ -435,6 +439,9 @@ IWidget.prototype.paint = function (onInit) {
         true);
 
     this.content.setAttribute("src", this.codeURL);
+    if (!onInit) {
+        this.element.classList.add('in');
+    }
 };
 
 IWidget.prototype.load = function () {
@@ -484,17 +491,18 @@ IWidget.prototype.setRefusedVersion = function (v) {
     }
 
     this.refusedVersion = v;
-    $("version_button_" + this.id).hide();
+    document.getElementById("version_button_" + this.id).hide();
 
     var iwidgetUrl = Wirecloud.URLs.IWIDGET_ENTRY.evaluate({
-        workspace_id: this.layout.dragboard.workspaceId,
-        tab_id: this.layout.dragboard.tabId,
+        workspace_id: this.layout.dragboard.workspace.id,
+        tab_id: this.layout.dragboard.tab.id,
         iwidget_id: this.id
     });
     Wirecloud.io.makeRequest(iwidgetUrl, {
         method: 'POST',
         contentType: 'application/json',
-        postBody: Object.toJSON({
+        requestHeaders: {'Accept': 'application/json'},
+        postBody: JSON.stringify({
             refused_version: this.refusedVersion.text,
             id: this.id
         }),
@@ -537,18 +545,19 @@ IWidget.prototype.upgradeIWidget = function () {
         source: this.internal_iwidget.widget.getLastVersion().source
     };
     var url = Wirecloud.URLs.IWIDGET_VERSION_ENTRY.evaluate({
-        workspace_id: this.layout.dragboard.workspaceId,
-        tab_id: this.layout.dragboard.tabId,
+        workspace_id: this.layout.dragboard.workspace.id,
+        tab_id: this.layout.dragboard.tab.id,
         iwidget_id: this.id
     });
 
     Wirecloud.io.makeRequest(url, {
         method: 'PUT',
+        contentType: 'application/json',
+        requestHeaders: {'Accept': 'application/json'},
+        postBody: JSON.stringify(data),
         onSuccess: onUpgradeOk.bind(this),
         onFailure: onUpgradeError.bind(this),
-        onException: onUpgradeError.bind(this),
-        postBody: Object.toJSON(data),
-        contentType: 'application/json'
+        onException: onUpgradeError.bind(this)
     });
 };
 
@@ -601,29 +610,10 @@ IWidget.prototype.remove = function (orderFromServer) {
         return;
     }
 
-    this.log(gettext('iWidget deleted'), Constants.Logging.INFO_MSG);
-
-    var dragboard = this.layout.dragboard;
-    if (isElement(this.element.parentNode)) {
-        this.layout.removeIWidget(this, true);
-    }
-
-    this.element = null;
-
     if (!orderFromServer) {
-        var onError = function (transport, e) {
-            Wirecloud.GlobalLogManager.formatAndLog(gettext("Error removing iwidget from persistence: %(errorMsg)s."), transport, e);
-        };
-
-        var uri = Wirecloud.URLs.IWIDGET_ENTRY.evaluate({
-            workspace_id: dragboard.workspaceId,
-            tab_id: dragboard.tabId,
-            iwidget_id: this.id
-        });
-        Wirecloud.io.makeRequest(uri, {
-            method: 'DELETE',
-            onFailure: onError.bind(this)
-        });
+        this.internal_iwidget.remove();
+    } else {
+        this._iwidget_removed();
     }
 };
 
@@ -724,7 +714,7 @@ IWidget.prototype._recomputeWrapper = function (contentHeight) {
         wrapperHeight = 0;
     }
 
-    this.contentWrapper.setStyle({height: wrapperHeight + "px"});
+    this.contentWrapper.style.height = wrapperHeight + "px";
 };
 
 /**
@@ -784,7 +774,7 @@ IWidget.prototype._recomputeHeight = function (basedOnContent) {
             var processedSize = this.layout.adaptHeight(contentHeight, fullSize);
             contentHeight = processedSize.inPixels;
             this.height = processedSize.inLU;
-            this.content.setStyle({height: contentHeight + "px"});
+            this.content.style.height = contentHeight + "px";
         } else {
             // Based on full widget height
             contentHeight = this.layout.getHeightInPixels(this.height);
@@ -795,7 +785,7 @@ IWidget.prototype._recomputeHeight = function (basedOnContent) {
                 contentHeight = 0;
             }
 
-            this.content.setStyle({height: contentHeight + "px"});
+            this.content.style.height = contentHeight + "px";
             this.contentHeight = Math.floor(this.layout.fromPixelsToVCells(contentHeight));
         }
 
@@ -809,7 +799,7 @@ IWidget.prototype._recomputeHeight = function (basedOnContent) {
     } else { // minimized
         this._recomputeWrapper();
         contentHeight = this.element.offsetHeight;
-        this.content.setStyle({height: "0px"});
+        this.content.style.height = "0px";
         this.height = Math.ceil(this.layout.fromPixelsToVCells(contentHeight));
     }
 
@@ -907,12 +897,13 @@ IWidget.prototype.setMinimizeStatus = function (newStatus, persistence, reserveS
     if (this.minimized) {
         if (this.onFreeLayout()) {
             // Floating widget
-            this.element.setStyle({"visibility": "hidden"});
-            this.iconElement.setStyle({"display": "block"});
+            this.element.style.visibility = "hidden";
+            this.iconElement.style.display = "block";
         } else {
             // Linked to the grid
-            this.contentWrapper.setStyle({"visibility": "hidden", "border": "0px"});
-            this.statusBar.setStyle({"display": "none"});
+            this.contentWrapper.style.visibility = "hidden";
+            this.contentWrapper.style.border = "0px";
+            this.statusBar.style.display = "none";
             this.minimizeButton.setTitle(gettext("Maximize"));
             this.minimizeButton.removeClassName("icon-minus");
             this.minimizeButton.addClassName("icon-plus");
@@ -921,15 +912,16 @@ IWidget.prototype.setMinimizeStatus = function (newStatus, persistence, reserveS
         this.minimizeButton.setTitle(gettext("Minimize"));
         this.minimizeButton.removeClassName("icon-plus");
         this.minimizeButton.addClassName("icon-minus");
-        this.contentWrapper.setStyle({"visibility": "", "border": ""});
+        this.contentWrapper.style.visibility = "";
+        this.contentWrapper.style.border = "";
 
         if (this.onFreeLayout()) {
             // Floating widget
-            this.element.setStyle({"visibility": ""});
-            this.iconElement.setStyle({"display": "none"});
+            this.element.style.visibility = "";
+            this.iconElement.style.display = "none";
         } else {
             //Linked to the grid
-            this.statusBar.setStyle({"display": ""});
+            this.statusBar.style.display = "";
         }
     }
 
@@ -987,25 +979,37 @@ IWidget.prototype._updateErrorInfo = function _updateErrorInfo() {
     this.errorButton.setTitle(label);
 };
 
+/**
+ * @private
+ */
+IWidget.prototype._iwidget_removed = function _iwidget_removed() {
+    var dragboard = this.layout.dragboard;
+    if (Wirecloud.Utils.XML.isElement(this.element.parentNode)) {
+        this.layout.removeIWidget(this, true);
+    }
+
+    this.element = null;
+};
+
 /**
  * Logs a success
  */
 IWidget.prototype.log = function (msg, level) {
-    level = level != null ? level : Constants.Logging.ERROR_MSG;
+    level = level != null ? level : Wirecloud.constants.LOGGING.ERROR_MSG;
 
     this.internal_iwidget.logManager.log(msg, level);
 };
 
 IWidget.prototype.highlight = function () {
     if (this.isVisible()) {
-        this.element.addClassName('highlighted');
+        this.element.classList.add('highlighted');
 
         if (this.highlightTimeout !== null) {
             clearTimeout(this.highlightTimeout);
         }
 
         this.highlightTimeout = setTimeout(function () {
-                this.element.removeClassName('highlighted');
+                this.element.classList.remove('highlighted');
                 this.highlightTimeout = null;
             }.bind(this),
             15000);
@@ -1030,54 +1034,10 @@ IWidget.prototype.is_shared_workspace = function () {
     return this.internal_iwidget.workspace.isShared();
 };
 
-/**
- * Saves the iwidget into persistence. Used only for the first time, that is,
- * for creating iwidgets.
- */
-IWidget.prototype.save = function (options) {
-    function onSuccess(transport) {
-        var iwidgetInfo = JSON.parse(transport.responseText);
-        this.internal_iwidget.id = iwidgetInfo['id'];
-        this.codeURL = this.internal_iwidget.widget.code_url + "#id=" + this.id;
-        this.layout.dragboard.addIWidget(this, iwidgetInfo, options);
-    }
-
-    function onError(transport, e) {
-        Wirecloud.GlobalLogManager.formatAndLog(gettext("Error adding iwidget to persistence: %(errorMsg)s."), transport, e);
-        this.destroy();
-    }
-
-    var url = Wirecloud.URLs.IWIDGET_COLLECTION.evaluate({
-        tab_id: this.layout.dragboard.tabId,
-        workspace_id: this.layout.dragboard.workspaceId
-    });
-
-    var data = Object.toJSON({
-        'widget': this.internal_iwidget.widget.id,
-        'left': this.position.x,
-        'top': this.position.y,
-        'icon_left': this.iconPosition.x,
-        'icon_top': this.iconPosition.y,
-        'zIndex': this.zPos,
-        'width': this.contentWidth,
-        'height': this.contentHeight,
-        'name': this.name,
-        'layout': this.onFreeLayout() ? 1 : 0
-    });
-    Wirecloud.io.makeRequest(url, {
-        method: 'POST',
-        contentType: 'application/json',
-        postBody: data,
-        onSuccess: onSuccess.bind(this),
-        onFailure: onError.bind(this),
-        onException: onError.bind(this)
-    });
-};
-
 /**
  * This function migrates this iwidget form a layout to another
  *
- * @param {DragboardLayout} newLayout the layout where the iWidget will be moved
+ * @param {Wirecloud.ui.DragboardLayout} newLayout the layout where the iWidget will be moved
  *                          to.
  */
 IWidget.prototype.moveToLayout = function (newLayout) {
@@ -1111,7 +1071,7 @@ IWidget.prototype.moveToLayout = function (newLayout) {
 
     // Force an unload event
     if (dragboardChange) {
-        OpManagerFactory.getInstance().iwidgetUnloaded(this.id);
+        this.internal_iwidget._notifyUnloaded();
     }
 
     affectedWidgetsRemoving = oldLayout.removeIWidget(this, dragboardChange);
@@ -1196,21 +1156,21 @@ IWidget.prototype.moveToLayout = function (newLayout) {
         iWidgetInfo['icon_top'] = this.iconPosition.y;
         iWidgetInfo['icon_left'] = this.iconPosition.x;
         iWidgetInfo['zIndex'] = this.zPos;
-        iWidgetInfo['tab'] = this.layout.dragboard.tabId;
+        iWidgetInfo['tab'] = this.layout.dragboard.tab.id;
 
         data.push(iWidgetInfo);
 
         var url = Wirecloud.URLs.IWIDGET_COLLECTION.evaluate({
-            workspace_id: oldLayout.dragboard.workspaceId,
-            tab_id: oldLayout.dragboard.tabId
+            workspace_id: oldLayout.dragboard.workspace.id,
+            tab_id: oldLayout.dragboard.tab.id
         });
         Wirecloud.io.makeRequest(url, {
             method: 'PUT',
             contentType: 'application/json',
-            postBody: Object.toJSON(data),
+            requestHeaders: {'Accept': 'application/json'},
+            postBody: JSON.stringify(data),
             onSuccess: onSuccess.bind(this),
             onFailure: onError.bind(this),
-            contentType: 'application/json'
         });
     }
 };
