@@ -19,7 +19,7 @@
  *
  */
 
-/*global CatalogueView, Constants, gettext, LayoutManagerFactory, LogManagerFactory, StyledElements, Wirecloud*/
+/*global CatalogueView, gettext, LayoutManagerFactory, StyledElements, Wirecloud*/
 
 (function () {
 
@@ -38,13 +38,13 @@
     MarketManager.getMarkets = function getMarkets(callback, onFailureCallback, onCompleteCallback) {
         Wirecloud.io.makeRequest(Wirecloud.URLs.MARKET_COLLECTION, {
             method: 'GET',
+            requestHeaders: {'Accept': 'application/json'},
             onSuccess: function onSuccess(transport) {
                 var raw_data = JSON.parse(transport.responseText);
                 callback(raw_data);
             },
             onFailure: function onFailure(transport) {
-                var msg = LogManagerFactory.getInstance().formatError(gettext("Error retrieving market list from the server: %(errorMsg)s."), transport);
-                LogManagerFactory.getInstance().log(msg);
+                var msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error retrieving market list from the server: %(errorMsg)s."), transport);
 
                 if (typeof onFailureCallback === 'function') {
                     onFailureCallback(msg);
@@ -74,10 +74,10 @@
 
         Wirecloud.io.makeRequest(url, {
             method: 'DELETE',
+            requestHeaders: {'Accept': 'application/json'},
             onSuccess: options.onSuccess,
             onFailure: function (transport) {
-                var msg = LogManagerFactory.getInstance().formatError(gettext("Error deleting marketplace: %(errorMsg)s."), transport);
-                LogManagerFactory.getInstance().log(msg);
+                var msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error deleting marketplace: %(errorMsg)s."), transport);
                 if (typeof options.onFailure === 'function') {
                     options.onFailure(msg);
                 }
@@ -94,6 +94,7 @@
         Wirecloud.io.makeRequest(Wirecloud.URLs.MARKET_COLLECTION, {
             method: 'POST',
             contentType: 'application/json',
+            requestHeaders: {'Accept': 'application/json'},
             postBody: JSON.stringify(market_info),
 
             onSuccess: function (transport) {
@@ -102,10 +103,8 @@
                 callback();
             },
             onFailure: function (transport) {
-                var msg = LogManagerFactory.getInstance().formatError(gettext("Error adding marketplace: %(errorMsg)s."), transport);
-                LogManagerFactory.getInstance().log(msg);
-                LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.ERROR_MSG);
-                LayoutManagerFactory.getInstance().log(msg);
+                var msg = Wirecloud.GlobalLogManager.formatAndLog(gettext("Error adding marketplace: %(errorMsg)s."), transport);
+                (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
             },
             onComplete: function () {
                 LayoutManagerFactory.getInstance()._notifyPlatformReady();
