@@ -1,39 +1,28 @@
 # -*- coding: utf-8 -*-
 
-#...............................licence...........................................
-#
-#     (C) Copyright 2008 Telefonica Investigacion y Desarrollo
-#     S.A.Unipersonal (Telefonica I+D)
-#
-#     This file is part of Morfeo EzWeb Platform.
-#
-#     Morfeo EzWeb Platform is free software: you can redistribute it and/or modify
-#     it under the terms of the GNU Affero General Public License as published by
-#     the Free Software Foundation, either version 3 of the License, or
-#     (at your option) any later version.
-#
-#     Morfeo EzWeb Platform is distributed in the hope that it will be useful,
-#     but WITHOUT ANY WARRANTY; without even the implied warranty of
-#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU Affero General Public License for more details.
-#
-#     You should have received a copy of the GNU Affero General Public License
-#     along with Morfeo EzWeb Platform.  If not, see <http://www.gnu.org/licenses/>.
-#
-#     Info about members and contributors of the MORFEO project
-#     is available at
-#
-#     http://morfeo-project.org
-#
-#...............................licence...........................................#
+# Copyright (c) 2011-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
+# This file is part of Wirecloud.
+
+# Wirecloud is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# Wirecloud is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-#
 import os
 import random
 
 from django.core.cache import cache
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 from django.db.models.signals import post_save
 from django.utils.translation import ugettext as _
 
@@ -42,6 +31,7 @@ from wirecloud.commons.models import TransModel
 from wirecloud.commons.utils.wgt import WgtFile
 
 
+@python_2_unicode_compatible
 class XHTML(models.Model):
 
     uri = models.CharField(_('URI'), max_length=255, unique=True)
@@ -52,16 +42,16 @@ class XHTML(models.Model):
     use_platform_style = models.BooleanField(_('Uses platform style'), default=False)
     cacheable = models.BooleanField(_('Cacheable'), default=True, blank=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.uri
 
-    def get_cache_key(self, domain):
+    def get_cache_key(self, domain, mode):
         version = cache.get('_widget_xhtml_version/' + str(self.id))
         if version is None:
             version = random.randrange(1, 100000)
             cache.set('_widget_xhtml_version/' + str(self.id), version)
 
-        return '_widget_xhtml/' + str(version) + '/' + domain + '/' + str(self.id)
+        return '_widget_xhtml/' + str(version) + '/' + domain + '/' + str(self.id) + '?mode=' + mode
 
     def delete(self, *args, **kwargs):
         old_id = self.id
@@ -82,6 +72,7 @@ class WidgetManager(models.Manager):
         return super(WidgetManager, self).get_query_set().select_related('resource')
 
 
+@python_2_unicode_compatible
 class Widget(models.Model):
 
     resource = models.OneToOneField('catalogue.CatalogueResource')
@@ -116,7 +107,7 @@ class Widget(models.Model):
         showcase_utils.wgt_deployer.undeploy(self.resource.vendor, self.resource.short_name, self.resource.version)
         super(Widget, self).delete(*args, **kwargs)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.uri
 
     def get_related_preferences(self):
@@ -125,13 +116,8 @@ class Widget(models.Model):
     def get_related_properties(self):
         return VariableDef.objects.filter(widget=self, aspect='PROP')
 
-    def get_related_events(self):
-        return VariableDef.objects.filter(widget=self, aspect='EVEN')
-
-    def get_related_slots(self):
-        return VariableDef.objects.filter(widget=self, aspect='SLOT')
-
 
+@python_2_unicode_compatible
 class VariableDef(TransModel):
 
     name = models.CharField(_('Name'), max_length=30)
@@ -149,8 +135,6 @@ class VariableDef(TransModel):
         ('EVEN', _('Event')),
         ('PREF', _('Preference')),
         ('PROP', _('Property')),
-        ('GCTX', _('WidgetContext')),
-        ('ECTX', _('ExternalContext')),
     )
     secure = models.BooleanField(_('Secure'), default=False)
     aspect = models.CharField(_('Aspect'), max_length=4, choices=ASPECTS)
@@ -164,31 +148,22 @@ class VariableDef(TransModel):
     widget = models.ForeignKey(Widget)
     order = models.IntegerField(default=0, blank=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.widget.uri + " " + self.aspect
 
-    #Values that cannot be public: passwords, produced events and consumed events
-    def has_public_value(self):
-        return self.type != 'P' and self.aspect != 'SLOT' and self.aspect != 'EVENT'
-
-    def get_default_value(self):
-        if self.default_value is None:
-            return ''
-        else:
-            return self.default_value
-
     class Meta:
         app_label = 'platform'
         db_table = 'wirecloud_variabledef'
 
 
+@python_2_unicode_compatible
 class UserPrefOption(TransModel):
 
     value = models.CharField(_('Value'), max_length=50)
     name = models.CharField(_('Name'), max_length=50)
     variableDef = models.ForeignKey(VariableDef)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.variableDef.widget.uri + " " + self.name
 
     class Meta:
@@ -196,13 +171,14 @@ class UserPrefOption(TransModel):
         db_table = 'wirecloud_userprefoption'
 
 
+@python_2_unicode_compatible
 class VariableDefAttr(models.Model):
 
     value = models.CharField(_('Value'), max_length=30)
     name = models.CharField(_('Name'), max_length=30)
     variableDef = models.ForeignKey(VariableDef)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.variableDef + self.name
 
     class Meta:
@@ -210,19 +186,6 @@ class VariableDefAttr(models.Model):
         db_table = 'wirecloud_variabledefattr'
 
 
-class ContextOption(models.Model):
-
-    concept = models.CharField(_('Concept'), max_length=256)
-    varDef = models.ForeignKey(VariableDef, verbose_name=_('Variable'))
-
-    def __unicode__(self):
-        return self.concept
-
-    class Meta:
-        app_label = 'platform'
-        db_table = 'wirecloud_contextoption'
-
-
 def create_widget_on_resource_creation(sender, instance, created, raw, **kwargs):
 
     from wirecloud.catalogue import utils as catalogue
