@@ -1,25 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
-# -*- coding: utf-8 -*-
-
 import codecs
 import os
 import rdflib
@@ -37,15 +34,14 @@ from wirecloud.catalogue import utils as catalogue
 from wirecloud.commons.utils.testcases import WirecloudTestCase
 from wirecloud.commons.utils.wgt import WgtDeployer, WgtFile
 from wirecloud.platform.get_data import get_global_workspace_data
-from wirecloud.platform.iwidget.utils import SaveIWidget, deleteIWidget
-from wirecloud.platform.models import IWidget, Tab, UserWorkspace, Variable, VariableValue, Workspace
+from wirecloud.platform.iwidget.utils import SaveIWidget
+from wirecloud.platform.models import IWidget, Tab, UserWorkspace, Variable, Workspace
 from wirecloud.platform.preferences.views import update_workspace_preferences
-from wirecloud.platform.workspace.packageCloner import PackageCloner
-from wirecloud.platform.workspace.mashupTemplateGenerator import build_template_from_workspace, build_rdf_template_from_workspace
+from wirecloud.platform.workspace.mashupTemplateGenerator import build_xml_template_from_workspace, build_rdf_template_from_workspace
 from wirecloud.platform.workspace.mashupTemplateParser import buildWorkspaceFromTemplate, fillWorkspaceUsingTemplate
 import wirecloud.platform.workspace.utils
 from wirecloud.platform.workspace.utils import sync_base_workspaces
-from wirecloud.platform.workspace.views import createEmptyWorkspace, linkWorkspace
+from wirecloud.platform.workspace.views import createEmptyWorkspace
 
 
 # Avoid nose to repeat these tests (they are run through wirecloud/tests/__init__.py)
@@ -103,104 +99,6 @@ class WorkspaceTestCase(CacheTestCase):
         self.assertEqual(data['shared'], False)
     test_create_empty_workspace.tags = ('fiware-ut-3',)
 
-    def test_link_workspace(self):
-
-        workspace = Workspace.objects.get(pk=1)
-
-        alternative_user = User.objects.get(username='test2')
-        new_workspace = linkWorkspace(alternative_user, workspace.id, self.user)
-
-        all_variables = VariableValue.objects.filter(variable__iwidget__tab__workspace=workspace)
-        initial_vars = all_variables.filter(user=self.user)
-        cloned_vars = all_variables.filter(user=alternative_user)
-
-        self.assertEqual(new_workspace.user, alternative_user)
-        self.assertEqual(workspace.creator, self.user)
-        self.assertEqual(new_workspace.workspace, workspace)
-        self.assertEqual(initial_vars.count(), cloned_vars.count())
-
-    def test_clone_workspace(self):
-
-        workspace = Workspace.objects.get(pk=1)
-
-        packageCloner = PackageCloner()
-        cloned_workspace = packageCloner.clone_tuple(workspace)
-
-        self.assertNotEqual(workspace, cloned_workspace)
-        self.assertEqual(cloned_workspace.users.count(), 0)
-
-        original_iwidgets = IWidget.objects.filter(tab__workspace=workspace)
-        cloned_iwidgets = IWidget.objects.filter(tab__workspace=cloned_workspace)
-        self.assertEqual(original_iwidgets.count(), cloned_iwidgets.count())
-        self.assertNotEqual(original_iwidgets[0].id, cloned_iwidgets[0].id)
-
-        original_variables = Variable.objects.filter(iwidget__tab__workspace=workspace)
-        cloned_variables = Variable.objects.filter(iwidget__tab__workspace=cloned_workspace)
-
-        self.assertEqual(original_variables.count(), cloned_variables.count())
-        self.assertNotEqual(original_variables[0].id, cloned_variables[0].id)
-
-    def test_merge_workspaces(self):
-
-        workspace = Workspace.objects.get(pk=1)
-
-        packageCloner = PackageCloner()
-        cloned_workspace = packageCloner.clone_tuple(workspace)
-        linkWorkspace(self.user, cloned_workspace.id, self.user)
-
-        packageCloner = PackageCloner()
-        packageCloner.merge_workspaces(cloned_workspace, workspace, self.user)
-
-        # Check cache invalidation
-        data = json.loads(get_global_workspace_data(workspace, self.user).get_data())
-        tab_list = data['tabs']
-
-        self.assertEqual(len(tab_list), 2)
-
-    def test_shared_workspace(self):
-
-        from django.conf import settings
-        if not hasattr(settings, 'WORKSPACE_MANAGERS') or 'wirecloud.platform.workspace.workspace_managers.OrganizationWorkspaceManager' not in settings.WORKSPACE_MANAGERS:
-            raise unittest.SkipTest('OrganizationWorkspaceManager not enabled')
-
-        workspace = Workspace.objects.get(pk=1)
-
-        # Create a new group and share the workspace with it
-        group = Group.objects.create(name='test_users')
-        workspace.targetOrganizations.add(group)
-
-        other_user = User.objects.get(username='test2')
-        other_user.groups.add(group)
-        other_user.save()
-
-        # Sync shared workspaces
-        sync_base_workspaces(other_user)
-
-        # Check that other_user can access to the shared workspace
-        data = json.loads(get_global_workspace_data(workspace, other_user).get_data())
-        iwidget_list = data['tabs'][0]['iwidgets']
-        self.assertEqual(len(iwidget_list), 2)
-
-        # Add a new iWidget to the workspace
-        tab = Tab.objects.get(pk=1)
-        iwidget_data = {
-            'widget': 'Test/Test Widget/1.0.0',
-            'name': 'test',
-            'top': 0,
-            'left': 0,
-            'width': 2,
-            'height': 2,
-            'zIndex': 1,
-            'layout': 0,
-            'icon_top': 0,
-            'icon_left': 0
-        }
-        SaveIWidget(iwidget_data, self.user, tab, {})
-
-        data = json.loads(get_global_workspace_data(workspace, other_user).get_data())
-        iwidget_list = data['tabs'][0]['iwidgets']
-        self.assertEqual(len(iwidget_list), 3)
-
 
 class WorkspaceCacheTestCase(CacheTestCase):
 
@@ -214,7 +112,11 @@ class WorkspaceCacheTestCase(CacheTestCase):
         self.workspace = Workspace.objects.get(pk=1)
 
         # Fill cache
-        get_global_workspace_data(self.workspace, self.user)
+        self.initial_info = get_global_workspace_data(self.workspace, self.user)
+
+    def test_workspace_data_is_cached(self):
+        workspace_info = get_global_workspace_data(self.workspace, self.user)
+        self.assertEqual(self.initial_info.timestamp, workspace_info.timestamp)
 
     def test_variable_updating_invalidates_cache(self):
 
@@ -261,7 +163,7 @@ class WorkspaceCacheTestCase(CacheTestCase):
 
     def test_widget_deletion_invalidates_cache(self):
 
-        deleteIWidget(IWidget.objects.get(pk=1), self.user)
+        IWidget.objects.get(pk=1).delete()
         data = json.loads(get_global_workspace_data(self.workspace, self.user).get_data())
         iwidget_list = data['tabs'][0]['iwidgets']
         self.assertEqual(len(iwidget_list), 1)
@@ -368,8 +270,8 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
         addr = graph.objects(mashup_uri, self.VCARD['addr']).next()
         self.assertRDFElement(graph, addr, self.VCARD, 'email', u'a@b.com')
 
-        author = graph.objects(mashup_uri, self.DCTERMS['creator']).next()
-        self.assertRDFElement(graph, author, self.FOAF, 'name', u'test')
+        authors = graph.objects(mashup_uri, self.DCTERMS['creator']).next()
+        self.assertRDFElement(graph, authors, self.FOAF, 'name', u'test')
 
     def check_empty_rdf_wiring_info(self, graph, mashup_uri):
 
@@ -378,16 +280,16 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
         self.assertRDFCount(graph, wiring, self.WIRE_M, 'hasiOperator', 0)
         self.assertRDFCount(graph, wiring, self.WIRE_M, 'hasWiringView', 0)
 
-    def test_build_template_from_workspace(self):
+    def test_build_xml_template_from_workspace(self):
 
         options = {
             'vendor': 'Wirecloud Test Suite',
             'name': 'Test Mashup',
             'version': '1',
-            'author': 'test',
+            'authors': 'test',
             'email': 'a@b.com',
         }
-        template = build_template_from_workspace(options, self.workspace, self.user)
+        template = build_xml_template_from_workspace(options, self.workspace, self.user)
 
         self.check_basic_xml_workspace_template_info(template)
         self.check_empty_xml_wiring_info(template)
@@ -402,12 +304,12 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
             'vendor': 'Wirecloud Test Suite',
             'name': 'Test Mashup',
             'version': '1',
-            'author': 'test',
+            'authors': 'test',
             'email': 'a@b.com',
-            'doc_uri': 'http://example.com/test-mashup/docs/index.html',
+            'doc': 'http://example.com/test-mashup/docs/index.html',
             'readOnlyWidgets': False,
         }
-        template = build_template_from_workspace(options, self.workspace_with_iwidgets, self.user)
+        template = build_xml_template_from_workspace(options, self.workspace_with_iwidgets, self.user)
 
         self.check_basic_xml_workspace_template_info(template)
 
@@ -420,19 +322,19 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
 
         self.check_empty_xml_wiring_info(template)
 
-    def test_build_template_from_workspace_read_only_widgets(self):
+    def test_build_xml_template_from_workspace_read_only_widgets(self):
 
         # Workspace with iwidgets
         options = {
             'vendor': 'Wirecloud Test Suite',
             'name': 'Test Mashup',
             'version': '1',
-            'author': 'test',
+            'authors': 'test',
             'email': 'a@b.com',
-            'doc_uri': 'http://example.com/test-mashup/docs/index.html',
+            'doc': 'http://example.com/test-mashup/docs/index.html',
             'readOnlyWidgets': True,
         }
-        template = build_template_from_workspace(options, self.workspace_with_iwidgets, self.user)
+        template = build_xml_template_from_workspace(options, self.workspace_with_iwidgets, self.user)
 
         self.check_basic_xml_workspace_template_info(template)
 
@@ -445,16 +347,16 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
 
         self.check_empty_xml_wiring_info(template)
 
-    test_build_template_from_workspace_read_only_widgets.tags = ('next',)
+    test_build_xml_template_from_workspace_read_only_widgets.tags = ('next',)
 
-    def test_build_template_from_workspace_forced_values(self):
+    def test_build_xml_template_from_workspace_forced_values(self):
 
         # Workspace with iwidgets
         options = {
             'vendor': 'Wirecloud Test Suite',
             'name': 'Test Mashup',
             'version': '1',
-            'author': 'test',
+            'authors': 'test',
             'email': 'a@b.com',
             'readOnlyWidgets': False,
             'parametrization': {
@@ -467,26 +369,26 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
                 'ioperators': {}
             },
         }
-        template = build_template_from_workspace(options, self.workspace_with_iwidgets, self.user)
+        template = build_xml_template_from_workspace(options, self.workspace_with_iwidgets, self.user)
         self.check_basic_xml_workspace_template_info(template)
 
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[1]/Preference[@name="username"]', 'readonly', 'true')
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[1]/Preference[@name="username"]', 'hidden', 'false', optional=True)
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[1]/Preference[@name="username"]', 'value', 'default')
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[1]/Preference[@name="password"]', 'readonly', 'true')
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[1]/Preference[@name="password"]', 'hidden', 'true')
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[1]/Preference[@name="password"]', 'value', 'initial text')
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="1"]/Preference[@name="username"]', 'readonly', 'true')
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="1"]/Preference[@name="username"]', 'hidden', 'false', optional=True)
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="1"]/Preference[@name="username"]', 'value', 'default')
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="1"]/Preference[@name="password"]', 'readonly', 'true')
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="1"]/Preference[@name="password"]', 'hidden', 'true')
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="1"]/Preference[@name="password"]', 'value', 'initial text')
 
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[2]/Preference[@name="username"]', 'readonly', 'false', optional=True)
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[2]/Preference[@name="username"]', 'hidden', 'false', optional=True)
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[2]/Preference[@name="username"]', 'value', 'test_username')
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[2]/Preference[@name="password"]', 'readonly', 'false', optional=True)
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[2]/Preference[@name="password"]', 'hidden', 'false', optional=True)
-        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[2]/Preference[@name="password"]', 'value', 'test_password')
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="2"]/Preference[@name="username"]', 'readonly', 'false', optional=True)
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="2"]/Preference[@name="username"]', 'hidden', 'false', optional=True)
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="2"]/Preference[@name="username"]', 'value', 'test_username')
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="2"]/Preference[@name="password"]', 'readonly', 'false', optional=True)
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="2"]/Preference[@name="password"]', 'hidden', 'false', optional=True)
+        self.assertXPathAttr(template, '/Template/Catalog.ResourceDescription/IncludedResources/Tab[1]/Resource[@id="2"]/Preference[@name="password"]', 'value', 'test_password')
 
         self.check_empty_xml_wiring_info(template)
 
-    test_build_template_from_workspace_forced_values.tags = ('next',)
+    test_build_xml_template_from_workspace_forced_values.tags = ('next',)
 
     def test_build_rdf_template_from_workspace(self):
 
@@ -494,7 +396,7 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
             'vendor': u'Wirecloud Test Suite',
             'name': u'Test Mashup',
             'version': u'1',
-            'author': u'test',
+            'authors': u'test',
             'email': u'a@b.com',
         }
         # Basic info
@@ -514,7 +416,7 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
             'vendor': u'Wirecloud Test Suite',
             'name': u'Test Mashup',
             'version': u'1',
-            'author': u'test',
+            'authors': u'test',
             'email': u'a@b.com',
             'readOnlyWidgets': False,
         }
@@ -555,7 +457,7 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
             'vendor': u'Wirecloud Test Suite',
             'name': u'Test Mashup',
             'version': u'1',
-            'author': u'test',
+            'authors': u'test',
             'email': u'a@b.com',
             'readOnlyWidgets': True,
         }
@@ -597,7 +499,7 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
             'vendor': 'Wirecloud Test Suite',
             'name': 'Test Mashup',
             'version': '1',
-            'author': 'test',
+            'authors': 'test',
             'email': 'a@b.com',
             'readOnlyWidgets': False,
             'parametrization': {
@@ -662,7 +564,7 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
             'vendor': u'Wirecloud Test Suite',
             'name': u'Test Mashup with ñ',
             'version': u'1',
-            'author': u'author with é',
+            'authors': u'author with é',
             'email': u'a@b.com',
             'readOnlyWidgets': True,
         }
@@ -679,8 +581,8 @@ class ParameterizedWorkspaceGenerationTestCase(WirecloudTestCase):
         addr = graph.objects(mashup_uri, self.VCARD['addr']).next()
         self.assertRDFElement(graph, addr, self.VCARD, 'email', u'a@b.com')
 
-        author = graph.objects(mashup_uri, self.DCTERMS['creator']).next()
-        self.assertRDFElement(graph, author, self.FOAF, 'name', u'author with é')
+        authors = graph.objects(mashup_uri, self.DCTERMS['creator']).next()
+        self.assertRDFElement(graph, authors, self.FOAF, 'name', u'author with é')
 
 
 class ParameterizedWorkspaceParseTestCase(CacheTestCase):
